@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+
 # Copyright (c) 2013 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -19,9 +21,10 @@ patches.patch_all()
 import os
 import sys
 
-from oslo_log import log
+import eventlet
+from eventlet import wsgi
+from oslo import i18n
 
-LOG = log.getLogger(__name__)
 
 # If ../sahara/__init__.py exists, add ../ to Python search path, so that
 # it will override what happens to be installed in /usr/(local/)lib/python...
@@ -34,7 +37,17 @@ if os.path.exists(os.path.join(possible_topdir,
     sys.path.insert(0, possible_topdir)
 
 
+# NOTE(slukjanov): i18n.enable_lazy() must be called before
+#                  sahara.utils.i18n._() is called to ensure it has the desired
+#                  lazy lookup behavior.
+i18n.enable_lazy()
+
+
 import sahara.main as server
+from sahara.openstack.common import log as logging
+
+
+LOG = logging.getLogger(__name__)
 
 
 def main():
@@ -44,19 +57,7 @@ def main():
 
     server.setup_sahara_api('all-in-one')
     server.setup_sahara_engine()
-    server.setup_auth_policy()
 
-    launcher = server.get_process_launcher()
-    LOG.warning("""
- __        __               _
- \ \      / /_ _ _ __ _ __ (_)_ __   __ _
-  \ \ /\ / / _` | '__| '_ \| | '_ \ / _` |
-   \ V  V / (_| | |  | | | | | | | | (_| |
-    \_/\_/ \__,_|_|  |_| |_|_|_| |_|\__, |
-                                    |___/
-
-Using the sahara-all entry point is now deprecated. Please use the sahara-api
-and sahara-engine entry points instead.
-    """)
-    server.launch_api_service(
-        launcher, server.SaharaWSGIService("sahara-all", app))
+    from oslo.config import cfg
+    wsgi.server(eventlet.listen((cfg.CONF.host, cfg.CONF.port), backlog=500),
+                app, log=logging.WritableLogger(LOG), debug=False)
