@@ -15,6 +15,8 @@
 
 from oslo.config import cfg
 
+from sahara import exceptions as ex
+from sahara.i18n import _
 from sahara.openstack.common import log
 from sahara import version
 
@@ -33,7 +35,7 @@ edp_opts = [
     cfg.IntOpt('job_binary_max_KB',
                default=5120,
                help='Maximum length of job binary data in kilobytes that '
-                    'may be stored or retrieved in a single operation')
+                    'may be stored or retrieved in a single operation.')
 ]
 
 networking_opts = [
@@ -81,34 +83,24 @@ CONF.register_cli_opts(cli_opts)
 CONF.register_opts(networking_opts)
 CONF.register_opts(edp_opts)
 
-ARGV = []
-
-
-def parse_configs(argv=None, conf_files=None):
-    if argv is not None:
-        global ARGV
-        ARGV = argv
-
-    # TODO(slukjanov): remove this code (temp to migrate to the new name)
-    if conf_files is None:
-        conf_files = []
-    conf_files += cfg.find_config_files(project="sahara")
 
+def parse_configs(conf_files=None):
     try:
         version_string = version.version_info.version_string()
-        CONF(ARGV, project='sahara', version=version_string,
+        CONF(project='sahara', version=version_string,
              default_config_files=conf_files)
     except cfg.RequiredOptError as roe:
-        # TODO(slukjanov): replace RuntimeError with concrete exception
-        raise RuntimeError("Option '%s' is required for config group "
-                           "'%s'" % (roe.opt_name, roe.group.name))
+        raise ex.ConfigurationError(
+            _("Option '%(option)s' is required for config group '%(group)s'") %
+            {'option': roe.opt_name, 'group': roe.group.name})
     validate_configs()
 
 
 def validate_network_configs():
     if CONF.use_namespaces and not CONF.use_neutron:
-        raise RuntimeError('use_namespaces can not be set to "True" when '
-                           'use_neutron is set to "False"')
+        raise ex.ConfigurationError(
+            _('use_namespaces can not be set to "True" when use_neutron '
+              'is set to "False"'))
 
 
 def validate_configs():
