@@ -13,15 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import threading
-
 import eventlet
-from eventlet import corolocal
+from eventlet.green import threading
+from eventlet.green import time
 from eventlet import greenpool
 from eventlet import semaphore
 from oslo.config import cfg
 
-from sahara import exceptions
+from sahara import exceptions as ex
+from sahara.i18n import _
+from sahara.i18n import _LE
+from sahara.i18n import _LW
 from sahara.openstack.common import log as logging
 
 
@@ -41,9 +43,12 @@ class Context(object):
                  roles=None,
                  is_admin=None,
                  remote_semaphore=None,
+                 auth_uri=None,
                  **kwargs):
         if kwargs:
-            LOG.warn('Arguments dropped when creating context: %s', kwargs)
+            LOG.warn(_LW('Arguments dropped when creating context: %s'),
+                     kwargs)
+
         self.user_id = user_id
         self.tenant_id = tenant_id
         self.token = token
@@ -54,6 +59,10 @@ class Context(object):
         self.remote_semaphore = remote_semaphore or semaphore.Semaphore(
             CONF.cluster_remote_threshold)
         self.roles = roles
+        if auth_uri:
+            self.auth_uri = auth_uri
+        else:
+            self.auth_uri = _get_auth_uri()
 
     def clone(self):
         return Context(
@@ -65,7 +74,8 @@ class Context(object):
             self.tenant_name,
             self.roles,
             self.is_admin,
-            self.remote_semaphore)
+            self.remote_semaphore,
+            self.auth_uri)
 
     def to_dict(self):
         return {
@@ -77,31 +87,30 @@ class Context(object):
             'tenant_name': self.tenant_name,
             'is_admin': self.is_admin,
             'roles': self.roles,
+            'auth_uri': self.auth_uri,
         }
 
     def is_auth_capable(self):
-        return self.service_catalog and self.token and self.tenant_id and \
-            self.user_id
+        return (self.service_catalog and self.token and self.tenant_id and
+                self.user_id)
 
 
 def get_admin_context():
     return Context(is_admin=True)
 
 
-_CTXS = threading.local()
-_CTXS._curr_ctxs = {}
+_CTX_STORE = threading.local()
+_CTX_KEY = 'current_ctx'
 
 
 def has_ctx():
-    ident = corolocal.get_ident()
-    return ident in _CTXS._curr_ctxs and _CTXS._curr_ctxs[ident]
+    return hasattr(_CTX_STORE, _CTX_KEY)
 
 
 def ctx():
     if not has_ctx():
-        # TODO(slukjanov): replace with specific error
-        raise RuntimeError("Context isn't available here")
-    return _CTXS._curr_ctxs[corolocal.get_ident()]
+        raise ex.IncorrectStateError(_("Context isn't available here"))
+    return getattr(_CTX_STORE, _CTX_KEY)
 
 
 def current():
@@ -109,13 +118,33 @@ def current():
 
 
 def set_ctx(new_ctx):
-    ident = corolocal.get_ident()
-
-    if not new_ctx and ident in _CTXS._curr_ctxs:
-        del _CTXS._curr_ctxs[ident]
+    if not new_ctx and has_ctx():
+        delattr(_CTX_STORE, _CTX_KEY)
 
     if new_ctx:
-        _CTXS._curr_ctxs[ident] = new_ctx
+        setattr(_CTX_STORE, _CTX_KEY, new_ctx)
+
+
+def _get_auth_uri():
+    if CONF.keystone_authtoken.auth_uri is not None:
+        auth_uri = CONF.keystone_authtoken.auth_uri
+    else:
+        if CONF.keystone_authtoken.identity_uri is not None:
+            identity_uri = CONF.keystone_authtoken.identity_uri
+        else:
+            host = CONF.keystone_authtoken.auth_host
+            port = CONF.keystone_authtoken.auth_port
+            protocol = CONF.keystone_authtoken.auth_protocol
+            identity_uri = '%s://%s:%s' % (protocol, host, port)
+
+        if CONF.use_identity_api_v3 is False:
+            auth_version = 'v2.0'
+        else:
+            auth_version = 'v3'
+
+        auth_uri = '%s/%s' % (identity_uri, auth_version)
+
+    return auth_uri
 
 
 def _wrapper(ctx, thread_description, thread_group, func, *args, **kwargs):
@@ -123,8 +152,9 @@ def _wrapper(ctx, thread_description, thread_group, func, *args, **kwargs):
         set_ctx(ctx)
         func(*args, **kwargs)
     except BaseException as e:
-        LOG.exception("Thread '%s' fails with exception: '%s'"
-                      % (thread_description, e))
+        LOG.exception(
+            _LE("Thread '%(thread)s' fails with exception: '%(exception)s'"),
+            {'thread': thread_description, 'exception': e})
         if thread_group and not thread_group.exc:
             thread_group.exc = e
             thread_group.failed_thread = thread_description
@@ -141,7 +171,9 @@ def spawn(thread_description, func, *args, **kwargs):
 
 
 class ThreadGroup(object):
-    """It is advised to use TreadGroup as a context manager instead
+    """ThreadGroup object.
+
+    It is advised to use TreadGroup as a context manager instead
     of instantiating and calling _wait() manually. The __exit__()
     guaranties to exit only after all child threads are done, even if
     spawning code have thrown an exception
@@ -172,7 +204,9 @@ class ThreadGroup(object):
     # * Oslo's ThreadGroup.wait() can exit before all threads are done
     #
     def _wait(self):
-        """It is preferred to use the class as a context manager and do not
+        """Using of _wait() method.
+
+        It is preferred to use the class as a context manager and do not
         use _wait() directly, see class docstring for an explanation.
         """
         with self.cv:
@@ -180,7 +214,7 @@ class ThreadGroup(object):
                 self.cv.wait()
 
         if self.exc:
-            raise exceptions.ThreadException(self.failed_thread, self.exc)
+            raise ex.ThreadException(self.failed_thread, self.exc)
 
     def __enter__(self):
         return self
@@ -199,4 +233,4 @@ class ThreadGroup(object):
 
 
 def sleep(seconds=0):
-    eventlet.sleep(seconds)
+    time.sleep(seconds)
