@@ -14,10 +14,12 @@
 # limitations under the License.
 #
 # Based on Neutron's migration/cli.py
+
+from __future__ import with_statement
 from logging import config as c
 
 from alembic import context
-from oslo_utils import importutils
+from oslo.utils import importutils
 from sqlalchemy import create_engine
 from sqlalchemy import pool
 
@@ -87,7 +89,6 @@ def run_migrations_online():
     finally:
         connection.close()
 
-
 if context.is_offline_mode():
     run_migrations_offline()
 else:
