@@ -23,7 +23,7 @@ from sahara.db.sqlalchemy import model_base as mb
 from sahara.db.sqlalchemy import types as st
 
 
-## Helpers
+# Helpers
 
 def _generate_unicode_uuid():
     return six.text_type(uuid.uuid4())
@@ -35,7 +35,7 @@ def _id_column():
                      default=_generate_unicode_uuid)
 
 
-## Main objects: Cluster, NodeGroup, Instance
+# Main objects: Cluster, NodeGroup, Instance
 
 class Cluster(mb.SaharaBase):
     """Contains all info about cluster."""
@@ -62,9 +62,11 @@ class Cluster(mb.SaharaBase):
     management_public_key = sa.Column(sa.Text, nullable=False)
     user_keypair_id = sa.Column(sa.String(80))
     status = sa.Column(sa.String(80))
-    status_description = sa.Column(sa.String(200))
+    status_description = sa.Column(st.LongText())
     info = sa.Column(st.JsonDictType())
     extra = sa.Column(st.JsonDictType())
+    rollback_info = sa.Column(st.JsonDictType())
+    sahara_info = sa.Column(st.JsonDictType())
     node_groups = relationship('NodeGroup', cascade="all,delete",
                                backref='cluster', lazy='joined')
     cluster_template_id = sa.Column(sa.String(36),
@@ -109,6 +111,9 @@ class NodeGroup(mb.SaharaBase):
     node_group_template = relationship('NodeGroupTemplate',
                                        backref="node_groups", lazy='joined')
     floating_ip_pool = sa.Column(sa.String(36))
+    security_groups = sa.Column(st.JsonListType())
+    auto_security_group = sa.Column(sa.Boolean())
+    open_ports = sa.Column(st.JsonListType())
 
     def to_dict(self):
         d = super(NodeGroup, self).to_dict()
@@ -136,7 +141,7 @@ class Instance(mb.SaharaBase):
     volumes = sa.Column(st.JsonListType())
 
 
-## Template objects: ClusterTemplate, NodeGroupTemplate, TemplatesRelation
+# Template objects: ClusterTemplate, NodeGroupTemplate, TemplatesRelation
 
 class ClusterTemplate(mb.SaharaBase):
     """Template for Cluster."""
@@ -190,6 +195,8 @@ class NodeGroupTemplate(mb.SaharaBase):
     volumes_size = sa.Column(sa.Integer)
     volume_mount_prefix = sa.Column(sa.String(80))
     floating_ip_pool = sa.Column(sa.String(36))
+    security_groups = sa.Column(st.JsonListType())
+    auto_security_group = sa.Column(sa.Boolean())
 
 
 class TemplatesRelation(mb.SaharaBase):
@@ -220,12 +227,15 @@ class TemplatesRelation(mb.SaharaBase):
                                        backref="templates_relations",
                                        lazy='joined')
     floating_ip_pool = sa.Column(sa.String(36))
+    security_groups = sa.Column(st.JsonListType())
+    auto_security_group = sa.Column(sa.Boolean())
 
 
-## EDP objects: DataSource, Job, Job Execution, JobBinary
+# EDP objects: DataSource, Job, Job Execution, JobBinary
 
 class DataSource(mb.SaharaBase):
-    """DataSource - represent a diffident types of data source,
+    """DataSource - represent a diffident types of data sources.
+
     e.g. Swift, Cassandra etc.
     """
 
@@ -245,8 +255,8 @@ class DataSource(mb.SaharaBase):
 
 
 class JobExecution(mb.SaharaBase):
-    """JobExecution - represent a job execution of specific cluster
-    """
+    """JobExecution - represent a job execution of specific cluster."""
+
     __tablename__ = 'job_executions'
 
     id = _id_column()
@@ -291,8 +301,7 @@ libs_association = sa.Table("libs_association",
 
 
 class Job(mb.SaharaBase):
-    """Job - description and location of a job binary
-    """
+    """Job - description and location of a job binary."""
 
     __tablename__ = 'jobs'
 
@@ -320,8 +329,8 @@ class Job(mb.SaharaBase):
 
 
 class JobBinaryInternal(mb.SaharaBase):
-    """JobBinaryInternal - raw binary storage for executable jobs
-    """
+    """JobBinaryInternal - raw binary storage for executable jobs."""
+
     __tablename__ = 'job_binary_internal'
 
     __table_args__ = (
@@ -336,8 +345,7 @@ class JobBinaryInternal(mb.SaharaBase):
 
 
 class JobBinary(mb.SaharaBase):
-    """JobBinary - raw binary storage for executable jobs
-    """
+    """JobBinary - raw binary storage for executable jobs."""
 
     __tablename__ = 'job_binaries'
 
