@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Hortonworks, Inc.
+# Copyright (c) 2013 Hortonworks, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,21 +14,24 @@
 # limitations under the License.
 
 import re
-import six
 
 from oslo.config import cfg
+import six
+
 
 from sahara import exceptions as e
+from sahara.i18n import _
 from sahara.plugins.general import exceptions as ex
 from sahara.plugins.general import utils
 from sahara.swift import swift_helper as h
 from sahara.topology import topology_helper as th
 
+
 CONF = cfg.CONF
 TOPOLOGY_CONFIG = {
-    "net.topology.node.switch.mapping.impl":
+    "topology.node.switch.mapping.impl":
     "org.apache.hadoop.net.ScriptBasedMapping",
-    "net.topology.script.file.name":
+    "topology.script.file.name":
     "/etc/hadoop/conf/topology.sh"
 }
 
@@ -131,16 +134,15 @@ class HdfsService(Service):
     def finalize_configuration(self, cluster_spec):
         nn_hosts = cluster_spec.determine_component_hosts('NAMENODE')
         if nn_hosts:
-            props = {'core-site': ['fs.defaultFS'],
-                     'hdfs-site': ['dfs.namenode.http-address',
-                                   'dfs.namenode.https-address']}
+            props = {'core-site': ['fs.default.name'],
+                     'hdfs-site': ['dfs.http.address', 'dfs.https.address']}
             self._replace_config_token(
                 cluster_spec, '%NN_HOST%', nn_hosts.pop().fqdn(), props)
 
         snn_hosts = cluster_spec.determine_component_hosts(
             'SECONDARY_NAMENODE')
         if snn_hosts:
-            props = {'hdfs-site': ['dfs.namenode.secondary.http-address']}
+            props = {'hdfs-site': ['dfs.secondary.http.address']}
             self._replace_config_token(
                 cluster_spec, '%SNN_HOST%', snn_hosts.pop().fqdn(), props)
 
@@ -165,22 +167,25 @@ class HdfsService(Service):
         if dn_node_groups:
             common_paths = self._get_common_paths(dn_node_groups)
         hdfs_site_config = cluster_spec.configurations['hdfs-site']
-        hdfs_site_config['dfs.namenode.name.dir'] = (
-            self._generate_storage_path(
-                nn_ng.storage_paths(), '/hadoop/hdfs/namenode'))
+        global_config = cluster_spec.configurations['global']
+        hdfs_site_config['dfs.name.dir'] = self._generate_storage_path(
+            nn_ng.storage_paths(), '/hadoop/hdfs/namenode')
+        global_config['dfs_name_dir'] = self._generate_storage_path(
+            nn_ng.storage_paths(), '/hadoop/hdfs/namenode')
         if common_paths:
-            hdfs_site_config['dfs.datanode.data.dir'] = (
-                self._generate_storage_path(
-                    common_paths, '/hadoop/hdfs/data'))
+            hdfs_site_config['dfs.data.dir'] = self._generate_storage_path(
+                common_paths, '/hadoop/hdfs/data')
+            global_config['dfs_data_dir'] = self._generate_storage_path(
+                common_paths, '/hadoop/hdfs/data')
 
     def register_service_urls(self, cluster_spec, url_info):
         namenode_ip = cluster_spec.determine_component_hosts(
             'NAMENODE').pop().management_ip
 
         ui_port = self._get_port_from_cluster_spec(cluster_spec, 'hdfs-site',
-                                                   'dfs.namenode.http-address')
+                                                   'dfs.http.address')
         nn_port = self._get_port_from_cluster_spec(cluster_spec, 'core-site',
-                                                   'fs.defaultFS')
+                                                   'fs.default.name')
 
         url_info['HDFS'] = {
             'Web UI': 'http://%s:%s' % (namenode_ip, ui_port),
@@ -188,16 +193,6 @@ class HdfsService(Service):
         }
         return url_info
 
-    def finalize_ng_components(self, cluster_spec):
-        hdfs_ng = cluster_spec.get_node_groups_containing_component(
-            'NAMENODE')[0]
-        components = hdfs_ng.components
-        if not cluster_spec.get_deployed_node_group_count('ZOOKEEPER_SERVER'):
-            zk_service = next(service for service in cluster_spec.services
-                              if service.name == 'ZOOKEEPER')
-            zk_service.deployed = True
-            components.append('ZOOKEEPER_SERVER')
-
     def is_mandatory(self):
         return True
 
@@ -205,26 +200,40 @@ class HdfsService(Service):
         return h.get_swift_configs()
 
 
-class MapReduce2Service(Service):
+class MapReduceService(Service):
     def __init__(self):
-        super(MapReduce2Service, self).__init__(
-            MapReduce2Service.get_service_id())
+        super(MapReduceService, self).__init__(
+            MapReduceService.get_service_id())
         self.configurations.add('mapred-site')
 
     @classmethod
     def get_service_id(cls):
-        return 'MAPREDUCE2'
+        return 'MAPREDUCE'
 
     def validate(self, cluster_spec, cluster):
-        count = cluster_spec.get_deployed_node_group_count('HISTORYSERVER')
+        count = cluster_spec.get_deployed_node_group_count('JOBTRACKER')
         if count != 1:
-            raise ex.InvalidComponentCountException('HISTORYSERVER', 1, count)
+            raise ex.InvalidComponentCountException('JOBTRACKER', 1, count)
+
+        count = cluster_spec.get_deployed_node_group_count('TASKTRACKER')
+        if not count:
+            raise ex.InvalidComponentCountException(
+                'TASKTRACKER', '> 0', count)
 
     def finalize_configuration(self, cluster_spec):
+        jt_hosts = cluster_spec.determine_component_hosts('JOBTRACKER')
+        if jt_hosts:
+            props = {'mapred-site': ['mapred.job.tracker',
+                                     'mapred.job.tracker.http.address',
+                                     'mapreduce.history.server.http.address']}
+
+            self._replace_config_token(
+                cluster_spec, '%JT_HOST%', jt_hosts.pop().fqdn(), props)
+
+        # HISTORYSERVER component now a part of MapReduce 1 in Ambari 1.6.0
         hs_hosts = cluster_spec.determine_component_hosts('HISTORYSERVER')
         if hs_hosts:
-            props = {'mapred-site': ['mapreduce.jobhistory.webapp.address',
-                                     'mapreduce.jobhistory.address']}
+            props = {'mapred-site': ['mapreduce.jobhistory.webapp.address']}
 
             self._replace_config_token(
                 cluster_spec, '%HS_HOST%', hs_hosts.pop().fqdn(), props)
@@ -235,97 +244,41 @@ class MapReduce2Service(Service):
             for prop in th.vm_awareness_mapred_config():
                 mapred_site_config[prop['name']] = prop['value']
 
+        # process storage paths to accommodate ephemeral or cinder storage
+        # NOTE:  mapred.system.dir is an HDFS namespace path (not a filesystem
+        # path) so the default path should suffice
+        tt_node_groups = cluster_spec.get_node_groups_containing_component(
+            'TASKTRACKER')
+        if tt_node_groups:
+            global_config = cluster_spec.configurations['global']
+            common_paths = self._get_common_paths(tt_node_groups)
+            mapred_site_config['mapred.local.dir'] = (
+                self._generate_storage_path(common_paths, '/hadoop/mapred'))
+            global_config['mapred_local_dir'] = self._generate_storage_path(
+                common_paths, '/hadoop/mapred')
+
+    def finalize_ng_components(self, cluster_spec):
+        # add HISTORYSERVER, since HDP 1.3.2 stack was
+        # modified in Ambari 1.5.1/1.6.0 to include this component
+        # in the MAPREDUCE service
+        ambari_server_ngs = (
+            cluster_spec.get_node_groups_containing_component('JOBTRACKER'))
+        for ng in ambari_server_ngs:
+            if 'HISTORYSERVER' not in ng.components:
+                ng.components.append('HISTORYSERVER')
+
     def register_service_urls(self, cluster_spec, url_info):
-        historyserver_ip = cluster_spec.determine_component_hosts(
-            'HISTORYSERVER').pop().management_ip
+        jobtracker_ip = cluster_spec.determine_component_hosts(
+            'JOBTRACKER').pop().management_ip
 
         ui_port = self._get_port_from_cluster_spec(
             cluster_spec, 'mapred-site', 'mapreduce.jobhistory.webapp.address')
-        hs_port = self._get_port_from_cluster_spec(
-            cluster_spec, 'mapred-site', 'mapreduce.jobhistory.address')
+        jt_port = self._get_port_from_cluster_spec(
+            cluster_spec, 'mapred-site', 'mapred.job.tracker')
 
-        url_info['MapReduce2'] = {
-            'Web UI': 'http://%s:%s' % (historyserver_ip, ui_port),
-            'History Server': '%s:%s' % (historyserver_ip, hs_port)
-        }
-        return url_info
-
-    def finalize_ng_components(self, cluster_spec):
-        mr2_ng = cluster_spec.get_node_groups_containing_component(
-            'HISTORYSERVER')[0]
-        components = mr2_ng.components
-        if 'HDFS_CLIENT' not in components:
-            components.append('HDFS_CLIENT')
-
-    def is_mandatory(self):
-        return True
-
-
-class YarnService(Service):
-    def __init__(self):
-        super(YarnService, self).__init__(
-            YarnService.get_service_id())
-        self.configurations.add('yarn-site')
-        self.configurations.add('capacity-scheduler')
-
-    @classmethod
-    def get_service_id(cls):
-        return 'YARN'
-
-    def validate(self, cluster_spec, cluster):
-        count = cluster_spec.get_deployed_node_group_count('RESOURCEMANAGER')
-        if count != 1:
-            raise ex.InvalidComponentCountException('RESOURCEMANAGER', 1,
-                                                    count)
-
-        count = cluster_spec.get_deployed_node_group_count('NODEMANAGER')
-        if not count:
-            raise ex.InvalidComponentCountException(
-                'NODEMANAGER', '> 0', count)
-
-    def finalize_configuration(self, cluster_spec):
-        rm_hosts = cluster_spec.determine_component_hosts('RESOURCEMANAGER')
-        if rm_hosts:
-            props = {'yarn-site': ['yarn.resourcemanager.'
-                                   'resource-tracker.address',
-                                   'yarn.resourcemanager.hostname',
-                                   'yarn.resourcemanager.address',
-                                   'yarn.resourcemanager.scheduler.address',
-                                   'yarn.resourcemanager.webapp.address',
-                                   'yarn.log.server.url',
-                                   'yarn.resourcemanager.admin.address']}
-
-            self._replace_config_token(
-                cluster_spec, '%RM_HOST%', rm_hosts.pop().fqdn(), props)
-
-        # data locality/rack awareness prop processing
-        mapred_site_config = cluster_spec.configurations['mapred-site']
-        if CONF.enable_data_locality:
-            for prop in th.vm_awareness_mapred_config():
-                mapred_site_config[prop['name']] = prop['value']
-
-        # process storage paths to accommodate ephemeral or cinder storage
-        yarn_site_config = cluster_spec.configurations['yarn-site']
-        nm_node_groups = cluster_spec.get_node_groups_containing_component(
-            'NODEMANAGER')
-        if nm_node_groups:
-            common_paths = self._get_common_paths(nm_node_groups)
-            yarn_site_config['yarn.nodemanager.local-dirs'] = (
-                self._generate_storage_path(common_paths,
-                                            '/hadoop/yarn/local'))
-
-    def register_service_urls(self, cluster_spec, url_info):
-        resourcemgr_ip = cluster_spec.determine_component_hosts(
-            'RESOURCEMANAGER').pop().management_ip
-
-        ui_port = self._get_port_from_cluster_spec(
-            cluster_spec, 'yarn-site', 'yarn.resourcemanager.webapp.address')
-        rm_port = self._get_port_from_cluster_spec(
-            cluster_spec, 'yarn-site', 'yarn.resourcemanager.address')
-
-        url_info['Yarn'] = {
-            'Web UI': 'http://%s:%s' % (resourcemgr_ip, ui_port),
-            'ResourceManager': '%s:%s' % (resourcemgr_ip, rm_port)
+        url_info['MapReduce'] = {
+            'Web UI': 'http://%s:%s' % (jobtracker_ip, ui_port),
+            'JobTracker': '%s:%s' % (jobtracker_ip, jt_port)
         }
         return url_info
 
@@ -351,7 +304,8 @@ class HiveService(Service):
         hive_servers = cluster_spec.determine_component_hosts('HIVE_SERVER')
         if hive_servers:
             props = {'global': ['hive_hostname'],
-                     'core-site': ['hadoop.proxyuser.hive.hosts']}
+                     'core-site': ['hadoop.proxyuser.hive.hosts'],
+                     'hive-site': ['javax.jdo.option.ConnectionURL']}
             self._replace_config_token(
                 cluster_spec, '%HIVE_HOST%', hive_servers.pop().fqdn(), props)
 
@@ -365,7 +319,7 @@ class HiveService(Service):
         if hive_mysql:
             self._replace_config_token(
                 cluster_spec, '%HIVE_MYSQL_HOST%', hive_mysql.pop().fqdn(),
-                {'hive-site': ['javax.jdo.option.ConnectionURL']})
+                {'global': ['hive_jdbc_connection_url']})
 
     def register_user_input_handlers(self, ui_handlers):
         ui_handlers['hive-site/javax.jdo.option.ConnectionUserName'] = (
@@ -377,18 +331,20 @@ class HiveService(Service):
         hive_site_config_map = configurations['hive-site']
         hive_site_config_map['javax.jdo.option.ConnectionUserName'] = (
             user_input.value)
+        global_config_map = configurations['global']
+        global_config_map['hive_metastore_user_name'] = user_input.value
 
     def _handle_user_property_metastore_pwd(self, user_input, configurations):
         hive_site_config_map = configurations['hive-site']
         hive_site_config_map['javax.jdo.option.ConnectionPassword'] = (
             user_input.value)
+        global_config_map = configurations['global']
+        global_config_map['hive_metastore_user_passwd'] = user_input.value
 
     def finalize_ng_components(self, cluster_spec):
         hive_ng = cluster_spec.get_node_groups_containing_component(
             'HIVE_SERVER')[0]
         components = hive_ng.components
-        if 'MAPREDUCE2_CLIENT' not in components:
-            components.append('MAPREDUCE2_CLIENT')
         if not cluster_spec.get_deployed_node_group_count('HIVE_METASTORE'):
             components.append('HIVE_METASTORE')
         if not cluster_spec.get_deployed_node_group_count('MYSQL_SERVER'):
@@ -399,32 +355,6 @@ class HiveService(Service):
             zk_service.deployed = True
             components.append('ZOOKEEPER_SERVER')
 
-    def pre_service_start(self, cluster_spec, ambari_info, started_services):
-        # this code is needed because of a bug in Ambari where hdfs dir's
-        # are only created at NN initial startup.  Remove this code when
-        # the bug is fixed in Ambari.
-        if 'HDFS' not in started_services:
-            return
-
-        # get any instance
-        with cluster_spec.servers[0].remote() as r:
-            r.execute_command('su -c "hadoop fs -mkdir /user/hive" '
-                              '-s /bin/sh hdfs')
-            r.execute_command('su -c "hadoop fs -chown -R '
-                              'hive:hdfs /user/hive" -s /bin/sh hdfs')
-
-            r.execute_command('su -c "hadoop fs -mkdir /apps/hive" '
-                              '-s /bin/sh hdfs')
-            r.execute_command('su -c "hadoop fs -chmod -R 755 /apps/hive" '
-                              '-s /bin/sh hdfs')
-
-            r.execute_command('su -c "hadoop fs -mkdir /apps/hive/warehouse" '
-                              '-s /bin/sh hdfs')
-            r.execute_command('su -c "hadoop fs -chown -R hive:hdfs '
-                              '/apps/hive/warehouse" -s /bin/sh hdfs')
-            r.execute_command('su -c "hadoop fs -chmod -R 777 '
-                              '/apps/hive/warehouse" -s /bin/sh hdfs')
-
 
 class WebHCatService(Service):
     def __init__(self):
@@ -458,8 +388,9 @@ class WebHCatService(Service):
 
         zk_servers = cluster_spec.determine_component_hosts('ZOOKEEPER_SERVER')
         if zk_servers:
+            zk_list = ['{0}:2181'.format(z.fqdn()) for z in zk_servers]
             self._replace_config_token(
-                cluster_spec, '%ZOOKEEPER_HOST%', zk_servers.pop().fqdn(),
+                cluster_spec, '%ZOOKEEPER_HOSTS%', ','.join(zk_list),
                 {'webhcat-site': ['templeton.zookeeper.hosts']})
 
     def finalize_ng_components(self, cluster_spec):
@@ -468,11 +399,8 @@ class WebHCatService(Service):
         components = webhcat_ng.components
         if 'HDFS_CLIENT' not in components:
             components.append('HDFS_CLIENT')
-        if 'MAPREDUCE2_CLIENT' not in components:
-            components.append('MAPREDUCE2_CLIENT')
-        # per AMBARI-3483
-        if 'YARN_CLIENT' not in components:
-            components.append('YARN_CLIENT')
+        if 'MAPREDUCE_CLIENT' not in components:
+            components.append('MAPREDUCE_CLIENT')
         if 'ZOOKEEPER_CLIENT' not in components:
             # if zk server isn't in cluster, add to ng
             if not cluster_spec.get_deployed_node_group_count(
@@ -484,30 +412,6 @@ class WebHCatService(Service):
                 components.append('ZOOKEEPER_SERVER')
             components.append('ZOOKEEPER_CLIENT')
 
-    def pre_service_start(self, cluster_spec, ambari_info, started_services):
-        # this code is needed because of a bug in Ambari where hdfs dir's
-        # are only created at NN initial startup.  Remove this code when
-        # the bug is fixed in Ambari.
-
-        if 'HDFS' not in started_services:
-            return
-
-        # get any instance
-        with cluster_spec.servers[0].remote() as r:
-            r.execute_command('su -c "hadoop fs -mkdir /user/hcat" '
-                              '-s /bin/sh hdfs')
-            r.execute_command('su -c "hadoop fs -chown -R hcat:hdfs '
-                              '/user/hcat" -s /bin/sh hdfs')
-            r.execute_command('su -c "hadoop fs -chmod -R 755 /user/hcat" '
-                              '-s /bin/sh hdfs')
-
-            r.execute_command('su -c "hadoop fs -mkdir /apps/webhcat" '
-                              '-s /bin/sh hdfs')
-            r.execute_command('su -c "hadoop fs -chown -R hcat:hdfs '
-                              '/apps/webhcat" -s /bin/sh hdfs')
-            r.execute_command('su -c "hadoop fs -chmod -R 755 /apps/webhcat" '
-                              '-s /bin/sh hdfs')
-
 
 class HBaseService(Service):
     property_map = {
@@ -544,7 +448,8 @@ class HBaseService(Service):
             'hbase-site/hbase.hregion.memstore.mslab.enabled',
             'global/regionserver_memstore_lab'],
         'hbase-site/hbase.hregion.memstore.flush.size': [
-            'hbase-site/hbase.hregion.memstore.flush.size'],
+            'hbase-site/hbase.hregion.memstore.flush.size',
+            'global/hregion_memstoreflushsize'],
         'hbase-site/hbase.client.scanner.caching': [
             'hbase-site/hbase.client.scanner.caching',
             'global/client_scannercaching'],
@@ -567,7 +472,6 @@ class HBaseService(Service):
         super(HBaseService, self).__init__(
             HBaseService.get_service_id())
         self.configurations.add('hbase-site')
-        #self.configurations.add('hbase-policy')
 
     @classmethod
     def get_service_id(cls):
@@ -616,8 +520,8 @@ class HBaseService(Service):
             configurations['global']['hbase_hdfs_root_dir'] = match.group(3)
         else:
             raise e.InvalidDataException(
-                "Invalid value for property 'hbase-site/hbase.rootdir' : %s" %
-                user_input.value)
+                _("Invalid value for property 'hbase-site/hbase.rootdir' : %s")
+                % user_input.value)
 
     def finalize_configuration(self, cluster_spec):
         nn_servers = cluster_spec.determine_component_hosts('NAMENODE')
@@ -628,28 +532,17 @@ class HBaseService(Service):
 
         zk_servers = cluster_spec.determine_component_hosts('ZOOKEEPER_SERVER')
         if zk_servers:
+            zk_list = [z.fqdn() for z in zk_servers]
             self._replace_config_token(
-                cluster_spec, '%ZOOKEEPER_HOST%', zk_servers.pop().fqdn(),
+                cluster_spec, '%ZOOKEEPER_HOSTS%', ','.join(zk_list),
                 {'hbase-site': ['hbase.zookeeper.quorum']})
 
     def finalize_ng_components(self, cluster_spec):
         hbase_ng = cluster_spec.get_node_groups_containing_component(
-            'HBASE_MASTER')
-        components = hbase_ng[0].components
+            'HBASE_MASTER')[0]
+        components = hbase_ng.components
         if 'HDFS_CLIENT' not in components:
             components.append('HDFS_CLIENT')
-
-        if not cluster_spec.get_deployed_node_group_count(
-                'HBASE_REGIONSERVER'):
-            components.append('HBASE_REGIONSERVER')
-        else:
-            hbase_ng = cluster_spec.get_node_groups_containing_component(
-                'HBASE_REGIONSERVER')
-        for ng in hbase_ng:
-            components = ng.components
-            if 'HDFS_CLIENT' not in components:
-                components.append('HDFS_CLIENT')
-
         if not cluster_spec.get_deployed_node_group_count('ZOOKEEPER_SERVER'):
             zk_service = next(service for service in cluster_spec.services
                               if service.name == 'ZOOKEEPER')
@@ -668,12 +561,9 @@ class ZookeeperService(Service):
 
     def validate(self, cluster_spec, cluster):
         count = cluster_spec.get_deployed_node_group_count('ZOOKEEPER_SERVER')
-        if count != 1:
+        if count < 1:
             raise ex.InvalidComponentCountException(
-                'ZOOKEEPER_SERVER', 1, count)
-
-    def is_mandatory(self):
-        return True
+                'ZOOKEEPER_SERVER', '1+', count)
 
 
 class OozieService(Service):
@@ -704,7 +594,7 @@ class OozieService(Service):
             self._replace_config_token(
                 cluster_spec, '%OOZIE_HOST%', oozie_server.fqdn(),
                 {'global': ['oozie_hostname'],
-                 'oozie-site': ['oozie.base.url']})
+                    'oozie-site': ['oozie.base.url']})
             self._replace_config_token(
                 cluster_spec, '%OOZIE_HOST%', ",".join(name_list),
                 {'core-site': ['hadoop.proxyuser.oozie.hosts']})
@@ -715,11 +605,8 @@ class OozieService(Service):
         components = oozie_ng.components
         if 'HDFS_CLIENT' not in components:
             components.append('HDFS_CLIENT')
-        if 'MAPREDUCE2_CLIENT' not in components:
-            components.append('MAPREDUCE2_CLIENT')
-        # per AMBARI-3483
-        if 'YARN_CLIENT' not in components:
-            components.append('YARN_CLIENT')
+        if 'MAPREDUCE_CLIENT' not in components:
+            components.append('MAPREDUCE_CLIENT')
         # ensure that mr and hdfs clients are colocated with oozie client
         client_ngs = cluster_spec.get_node_groups_containing_component(
             'OOZIE_CLIENT')
@@ -727,8 +614,8 @@ class OozieService(Service):
             components = ng.components
             if 'HDFS_CLIENT' not in components:
                 components.append('HDFS_CLIENT')
-            if 'MAPREDUCE2_CLIENT' not in components:
-                components.append('MAPREDUCE2_CLIENT')
+        if 'MAPREDUCE_CLIENT' not in components:
+            components.append('MAPREDUCE_CLIENT')
 
     def register_service_urls(self, cluster_spec, url_info):
         oozie_ip = cluster_spec.determine_component_hosts(
@@ -750,11 +637,15 @@ class OozieService(Service):
         oozie_site_config_map = configurations['oozie-site']
         oozie_site_config_map['oozie.service.JPAService.jdbc.username'] = (
             user_input.value)
+        global_config_map = configurations['global']
+        global_config_map['oozie_metastore_user_name'] = user_input.value
 
     def _handle_user_property_db_pwd(self, user_input, configurations):
         oozie_site_config_map = configurations['oozie-site']
         oozie_site_config_map['oozie.service.JPAService.jdbc.password'] = (
             user_input.value)
+        global_config_map = configurations['global']
+        global_config_map['oozie_metastore_user_passwd'] = user_input.value
 
 
 class GangliaService(Service):
@@ -783,7 +674,7 @@ class AmbariService(Service):
     def __init__(self):
         super(AmbariService, self).__init__(AmbariService.get_service_id())
         self.configurations.add('ambari')
-        #TODO(jspeidel): don't hard code default admin user
+        # TODO(jspeidel): don't hard code default admin user
         self.admin_user_name = 'admin'
 
     @classmethod
@@ -844,38 +735,5 @@ class SqoopService(Service):
         for ng in sqoop_ngs:
             if 'HDFS_CLIENT' not in ng.components:
                 ng.components.append('HDFS_CLIENT')
-            if 'MAPREDUCE2_CLIENT' not in ng.components:
-                ng.components.append('MAPREDUCE2_CLIENT')
-
-
-class NagiosService(Service):
-    def __init__(self):
-        super(NagiosService, self).__init__(NagiosService.get_service_id())
-
-    @classmethod
-    def get_service_id(cls):
-        return 'NAGIOS'
-
-    def finalize_ng_components(self, cluster_spec):
-        # per AMBARI-2946
-        nagios_ngs = (
-            cluster_spec.get_node_groups_containing_component('NAGIOS_SERVER'))
-        for ng in nagios_ngs:
-            if 'YARN_CLIENT' not in ng.components:
-                ng.components.append('YARN_CLIENT')
-            if 'MAPREDUCE2_CLIENT' not in ng.components:
-                ng.components.append('MAPREDUCE2_CLIENT')
-            if cluster_spec.get_deployed_node_group_count('OOZIE_SERVER'):
-                if 'OOZIE_CLIENT' not in ng.components:
-                    ng.components.append('OOZIE_CLIENT')
-            if cluster_spec.get_deployed_node_group_count('HIVE_SERVER'):
-                if 'HIVE_CLIENT' not in ng.components:
-                    ng.components.append('HIVE_CLIENT')
-                if 'HCAT' not in ng.components:
-                    if not cluster_spec.get_deployed_node_group_count(
-                            'HCATALOG'):
-                        hcat_service = next(service for service in
-                                            cluster_spec.services if
-                                            service.name == 'HCATALOG')
-                        hcat_service.deployed = True
-                    ng.components.append('HCAT')
+            if 'MAPREDUCE_CLIENT' not in ng.components:
+                ng.components.append('MAPREDUCE_CLIENT')
