@@ -18,14 +18,19 @@ import logging
 
 from oslo.config import cfg
 import pkg_resources as pkg
-import requests
 
 from sahara import context
 from sahara import exceptions as exc
+from sahara.i18n import _
+from sahara.i18n import _LC
+from sahara.i18n import _LE
+from sahara.i18n import _LI
+from sahara.i18n import _LW
 from sahara.plugins.general import exceptions as ex
 from sahara.plugins.hdp import clusterspec as cs
 from sahara.plugins.hdp import configprovider as cfgprov
 from sahara.plugins.hdp.versions import abstractversionhandler as avm
+from sahara.plugins.hdp.versions.version_1_3_2 import edp_engine
 from sahara.plugins.hdp.versions.version_1_3_2 import services
 from sahara import version
 
@@ -45,7 +50,8 @@ class VersionHandler(avm.AbstractVersionHandler):
     def _get_config_provider(self):
         if self.config_provider is None:
             self.config_provider = cfgprov.ConfigurationProvider(
-                json.load(pkg.resource_stream(version.version_info.package,
+                json.load(pkg.resource_stream(
+                          version.version_info.package,
                           'plugins/hdp/versions/version_1_3_2/resources/'
                           'ambari-config-resource.json')))
 
@@ -71,6 +77,17 @@ class VersionHandler(avm.AbstractVersionHandler):
         if cluster_template:
             cluster_spec = cs.ClusterSpec(cluster_template)
         else:
+            if scaled_groups:
+                for ng in cluster.node_groups:
+                    ng_id = ng['id']
+                    if (ng_id in scaled_groups and
+                       ng['count'] > scaled_groups[ng_id]):
+                            raise ex.ClusterCannotBeScaled(
+                                cluster.name,
+                                _('The HDP plugin does not support '
+                                  'the decommissioning of nodes '
+                                  'for HDP version 1.3.2'))
+
             cluster_spec = self.get_default_cluster_configuration()
             cluster_spec.create_operational_config(
                 cluster, user_inputs, scaled_groups)
@@ -103,8 +120,10 @@ class VersionHandler(avm.AbstractVersionHandler):
     def get_services_processor(self):
         return services
 
-    def get_resource_manager_uri(self, cluster):
-        return cluster['info']['MapReduce']['JobTracker']
+    def get_edp_engine(self, cluster, job_type):
+        if job_type in edp_engine.EdpOozieEngine.get_supported_job_types():
+            return edp_engine.EdpOozieEngine(cluster)
+        return None
 
 
 class AmbariClient():
@@ -120,24 +139,38 @@ class AmbariClient():
         return {"X-Requested-By": "sahara"}
 
     def _post(self, url, ambari_info, data=None):
+        if data:
+            LOG.debug('AmbariClient:_post call, url = ' + url +
+                      ' data = ' + str(data))
+        else:
+            LOG.debug('AmbariClient:_post call, url = ' + url)
+
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.post(url, data=data,
                             auth=(ambari_info.user, ambari_info.password),
                             headers=self._get_standard_headers())
 
     def _delete(self, url, ambari_info):
+        LOG.debug('AmbariClient:_delete call, url = ' + url)
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.delete(url,
                               auth=(ambari_info.user, ambari_info.password),
                               headers=self._get_standard_headers())
 
     def _put(self, url, ambari_info, data=None):
+        if data:
+            LOG.debug('AmbariClient:_put call, url = ' + url +
+                      ' data = ' + str(data))
+        else:
+            LOG.debug('AmbariClient:_put call, url = ' + url)
+
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         auth = (ambari_info.user, ambari_info.password)
         return session.put(url, data=data, auth=auth,
                            headers=self._get_standard_headers())
 
     def _get(self, url, ambari_info):
+        LOG.debug('AmbariClient:_get call, url = ' + url)
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.get(url, auth=(ambari_info.user, ambari_info.password),
                            headers=self._get_standard_headers())
@@ -150,16 +183,16 @@ class AmbariClient():
                             self.handler.get_version() + '"}}')
 
         if result.status_code != 201:
-            LOG.error('Create cluster command failed. %s' % result.text)
+            LOG.error(_LE('Create cluster command failed. %s') % result.text)
             raise ex.HadoopProvisionError(
-                'Failed to add cluster: %s' % result.text)
+                _('Failed to add cluster: %s') % result.text)
 
     def _add_configurations_to_cluster(
             self, cluster_spec, ambari_info, name):
 
-        existing_config_url = 'http://{0}/api/v1/clusters/{1}?fields=' \
-                              'Clusters/desired_configs'.format(
-                                  ambari_info.get_address(), name)
+        existing_config_url = ('http://{0}/api/v1/clusters/{1}?fields='
+                               'Clusters/desired_configs'.format(
+                                   ambari_info.get_address(), name))
 
         result = self._get(existing_config_url, ambari_info)
 
@@ -183,8 +216,8 @@ class AmbariClient():
         for config_name in configs:
             if config_name in existing_configs:
                 if config_name == 'core-site' or config_name == 'global':
-                    existing_version = existing_configs[config_name]['tag']\
-                        .lstrip('v')
+                    existing_version = (
+                        existing_configs[config_name]['tag'].lstrip('v'))
                     version = int(existing_version) + 1
                 else:
                     continue
@@ -193,15 +226,15 @@ class AmbariClient():
             clusters['desired_config'] = config_body
             config_body['type'] = config_name
             config_body['tag'] = 'v%s' % version
-            config_body['properties'] = \
-                cluster_spec.configurations[config_name]
+            config_body['properties'] = (
+                cluster_spec.configurations[config_name])
             result = self._put(config_url, ambari_info, data=json.dumps(body))
             if result.status_code != 200:
                 LOG.error(
-                    'Set configuration command failed. {0}'.format(
+                    _LE('Set configuration command failed. {0}').format(
                         result.text))
                 raise ex.HadoopProvisionError(
-                    'Failed to set configurations on cluster: %s'
+                    _('Failed to set configurations on cluster: %s')
                     % result.text)
 
     def _add_services_to_cluster(self, cluster_spec, ambari_info, name):
@@ -214,14 +247,15 @@ class AmbariClient():
                     ambari_info)
                 if result.status_code not in [201, 409]:
                     LOG.error(
-                        'Create service command failed. {0}'.format(
+                        _LE('Create service command failed. {0}').format(
                             result.text))
                     raise ex.HadoopProvisionError(
-                        'Failed to add services to cluster: %s' % result.text)
+                        _('Failed to add services to cluster: %s')
+                        % result.text)
 
     def _add_components_to_services(self, cluster_spec, ambari_info, name):
-        add_component_url = 'http://{0}/api/v1/clusters/{1}/services/{'\
-                            '2}/components/{3}'
+        add_component_url = ('http://{0}/api/v1/clusters/{1}/services/{'
+                             '2}/components/{3}')
         for service in cluster_spec.services:
             if service.deployed and service.name != 'AMBARI':
                 for component in service.components:
@@ -231,18 +265,18 @@ class AmbariClient():
                         ambari_info)
                     if result.status_code not in [201, 409]:
                         LOG.error(
-                            'Create component command failed. {0}'.format(
+                            _LE('Create component command failed. {0}').format(
                                 result.text))
                         raise ex.HadoopProvisionError(
-                            'Failed to add components to services: %s'
+                            _('Failed to add components to services: %s')
                             % result.text)
 
     def _add_hosts_and_components(
             self, cluster_spec, servers, ambari_info, name):
 
         add_host_url = 'http://{0}/api/v1/clusters/{1}/hosts/{2}'
-        add_host_component_url = 'http://{0}/api/v1/clusters/{1}' \
-                                 '/hosts/{2}/host_components/{3}'
+        add_host_component_url = ('http://{0}/api/v1/clusters/{1}'
+                                  '/hosts/{2}/host_components/{3}')
         for host in servers:
             hostname = host.instance.fqdn().lower()
             result = self._post(
@@ -250,12 +284,12 @@ class AmbariClient():
                 ambari_info)
             if result.status_code != 201:
                 LOG.error(
-                    'Create host command failed. {0}'.format(result.text))
+                    _LE('Create host command failed. {0}').format(result.text))
                 raise ex.HadoopProvisionError(
-                    'Failed to add host: %s' % result.text)
+                    _('Failed to add host: %s') % result.text)
 
             node_group_name = host.node_group.name
-            #TODO(jspeidel): ensure that node group exists
+            # TODO(jspeidel): ensure that node group exists
             node_group = cluster_spec.node_groups[node_group_name]
             for component in node_group.components:
                 # don't add any AMBARI components
@@ -265,20 +299,21 @@ class AmbariClient():
                         ambari_info)
                     if result.status_code != 201:
                         LOG.error(
-                            'Create host_component command failed. %s' %
+                            _LE('Create host_component command failed. %s'),
                             result.text)
                         raise ex.HadoopProvisionError(
-                            'Failed to add host component: %s' % result.text)
+                            _('Failed to add host component: %s')
+                            % result.text)
 
     def _install_services(self, cluster_name, ambari_info):
-        LOG.info('Installing required Hadoop services ...')
+        LOG.info(_LI('Installing required Hadoop services ...'))
 
         ambari_address = ambari_info.get_address()
-        install_url = 'http://{0}/api/v1/clusters/{' \
-                      '1}/services?ServiceInfo/state=INIT'.format(
-                      ambari_address, cluster_name)
-        body = '{"RequestInfo" : { "context" : "Install all services" },'\
-               '"Body" : {"ServiceInfo": {"state" : "INSTALLED"}}}'
+        install_url = ('http://{0}/api/v1/clusters/{'
+                       '1}/services?ServiceInfo/state=INIT'.format(
+                           ambari_address, cluster_name))
+        body = ('{"RequestInfo" : { "context" : "Install all services" },'
+                '"Body" : {"ServiceInfo": {"state" : "INSTALLED"}}}')
 
         result = self._put(install_url, ambari_info, data=body)
 
@@ -289,23 +324,23 @@ class AmbariClient():
                 ambari_info, cluster_name, request_id),
                 ambari_info)
             if success:
-                LOG.info("Install of Hadoop stack successful.")
+                LOG.info(_LI("Install of Hadoop stack successful."))
                 self._finalize_ambari_state(ambari_info)
             else:
-                LOG.critical('Install command failed.')
+                LOG.critical(_LC('Install command failed.'))
                 raise ex.HadoopProvisionError(
-                    'Installation of Hadoop stack failed.')
+                    _('Installation of Hadoop stack failed.'))
         elif result.status_code != 200:
             LOG.error(
-                'Install command failed. {0}'.format(result.text))
+                _LE('Install command failed. {0}').format(result.text))
             raise ex.HadoopProvisionError(
-                'Installation of Hadoop stack failed.')
+                _('Installation of Hadoop stack failed.'))
 
     def _get_async_request_uri(self, ambari_info, cluster_name, request_id):
-        return 'http://{0}/api/v1/clusters/{1}/requests/{' \
-               '2}/tasks?fields=Tasks/status'.format(
-               ambari_info.get_address(), cluster_name,
-               request_id)
+        return ('http://{0}/api/v1/clusters/{1}/requests/{'
+                '2}/tasks?fields=Tasks/status'.format(
+                    ambari_info.get_address(), cluster_name,
+                    request_id))
 
     def _wait_for_async_request(self, request_url, ambari_info):
         started = False
@@ -327,30 +362,33 @@ class AmbariClient():
         return started
 
     def _finalize_ambari_state(self, ambari_info):
-        LOG.info('Finalizing Ambari cluster state.')
+        LOG.info(_LI('Finalizing Ambari cluster state.'))
 
         persist_state_uri = 'http://{0}/api/v1/persist'.format(
             ambari_info.get_address())
         # this post data has non-standard format because persist
         # resource doesn't comply with Ambari API standards
-        persist_data = '{ "CLUSTER_CURRENT_STATUS":' \
-                       '"{\\"clusterState\\":\\"CLUSTER_STARTED_5\\"}" }'
+        persist_data = ('{ "CLUSTER_CURRENT_STATUS":'
+                        '"{\\"clusterState\\":\\"CLUSTER_STARTED_5\\"}" }')
         result = self._post(persist_state_uri, ambari_info, data=persist_data)
 
         if result.status_code != 201 and result.status_code != 202:
-            LOG.warning('Finalizing of Ambari cluster state failed. {0}'.
+            LOG.warning(_LW('Finalizing of Ambari cluster state failed. {0}').
                         format(result.text))
-            raise ex.HadoopProvisionError('Unable to finalize Ambari state.')
+            raise ex.HadoopProvisionError(_('Unable to finalize Ambari '
+                                            'state.'))
 
     def start_services(self, cluster_name, cluster_spec, ambari_info):
-        LOG.info('Starting Hadoop services ...')
-        LOG.info('Cluster name: {0}, Ambari server address: {1}'
-                 .format(cluster_name, ambari_info.get_address()))
-        start_url = 'http://{0}/api/v1/clusters/{1}/services?ServiceInfo/' \
-                    'state=INSTALLED'.format(
-                        ambari_info.get_address(), cluster_name)
-        body = '{"RequestInfo" : { "context" : "Start all services" },'\
-               '"Body" : {"ServiceInfo": {"state" : "STARTED"}}}'
+        LOG.info(_LI('Starting Hadoop services ...'))
+        LOG.info(_LI('Cluster name: %(cluster_name)s, Ambari server address: '
+                     '%(server_address)s'),
+                 {'cluster_name': cluster_name,
+                  'server_address': ambari_info.get_address()})
+        start_url = ('http://{0}/api/v1/clusters/{1}/services?ServiceInfo/'
+                     'state=INSTALLED'.format(
+                         ambari_info.get_address(), cluster_name))
+        body = ('{"RequestInfo" : { "context" : "Start all services" },'
+                '"Body" : {"ServiceInfo": {"state" : "STARTED"}}}')
 
         self._fire_service_start_notifications(
             cluster_name, cluster_spec, ambari_info)
@@ -363,19 +401,20 @@ class AmbariClient():
                                             request_id), ambari_info)
             if success:
                 LOG.info(
-                    "Successfully started Hadoop cluster '{0}'.".format(
+                    _LI("Successfully started Hadoop cluster '{0}'.").format(
                         cluster_name))
             else:
-                LOG.critical('Failed to start Hadoop cluster.')
+                LOG.critical(_LC('Failed to start Hadoop cluster.'))
                 raise ex.HadoopProvisionError(
-                    'Start of Hadoop services failed.')
+                    _('Start of Hadoop services failed.'))
 
         elif result.status_code != 200:
             LOG.error(
-                'Start command failed. Status: {0}, response: {1}'.
-                format(result.status_code, result.text))
+                _LE('Start command failed. Status: %(status)s, '
+                    'response: %(response)s'),
+                {'status': result.status_code, 'response': result.text})
             raise ex.HadoopProvisionError(
-                'Start of Hadoop services failed.')
+                _('Start of Hadoop services failed.'))
 
     def _exec_ambari_command(self, ambari_info, body, cmd_uri):
 
@@ -389,18 +428,19 @@ class AmbariClient():
             success = self._wait_for_async_request(href, ambari_info)
             if success:
                 LOG.info(
-                    "Successfully changed state of Hadoop components ")
+                    _LI("Successfully changed state of Hadoop components "))
             else:
-                LOG.critical('Failed to change state of Hadoop '
-                             'components')
-                raise RuntimeError('Failed to change state of Hadoop '
-                                   'components')
+                LOG.critical(_LC('Failed to change state of Hadoop '
+                                 'components'))
+                raise ex.HadoopProvisionError(
+                    _('Failed to change state of Hadoop components'))
 
         else:
             LOG.error(
-                'Command failed. Status: {0}, response: {1}'.
-                format(result.status_code, result.text))
-            raise RuntimeError('Hadoop/Ambari command failed.')
+                _LE('Command failed. Status: %(status)s, response: '
+                    '%(response)s'),
+                {'status': result.status_code, 'response': result.text})
+            raise ex.HadoopProvisionError(_('Hadoop/Ambari command failed.'))
 
     def _get_host_list(self, servers):
         host_list = [server.instance.fqdn().lower() for server in servers]
@@ -416,29 +456,30 @@ class AmbariClient():
                                servers, cluster_spec)
 
     def _install_components(self, ambari_info, auth, cluster_name, servers):
-        LOG.info('Starting Hadoop components while scaling up')
-        LOG.info('Cluster name {0}, Ambari server ip {1}'
-                 .format(cluster_name, ambari_info.get_address()))
+        LOG.info(_LI('Starting Hadoop components while scaling up'))
+        LOG.info(_LI('Cluster name %(cluster_name)s, Ambari server ip %(ip)s'),
+                 {'cluster_name': cluster_name,
+                  'ip': ambari_info.get_address()})
         # query for the host components on the given hosts that are in the
         # INIT state
-        #TODO(jspeidel): provide request context
+        # TODO(jspeidel): provide request context
         body = '{"HostRoles": {"state" : "INSTALLED"}}'
-        install_uri = 'http://{0}/api/v1/clusters/{' \
-                      '1}/host_components?HostRoles/state=INIT&' \
-                      'HostRoles/host_name.in({2})'.format(
-                      ambari_info.get_address(), cluster_name,
-                      self._get_host_list(servers))
+        install_uri = ('http://{0}/api/v1/clusters/{'
+                       '1}/host_components?HostRoles/state=INIT&'
+                       'HostRoles/host_name.in({2})'.format(
+                           ambari_info.get_address(), cluster_name,
+                           self._get_host_list(servers)))
         self._exec_ambari_command(ambari_info, body, install_uri)
 
     def _start_components(self, ambari_info, auth, cluster_name, servers,
                           cluster_spec):
         # query for all the host components in the INSTALLED state,
         # then get a list of the client services in the list
-        installed_uri = 'http://{0}/api/v1/clusters/{'\
-                        '1}/host_components?HostRoles/state=INSTALLED&'\
-                        'HostRoles/host_name.in({2})'.format(
-                            ambari_info.get_address(), cluster_name,
-                            self._get_host_list(servers))
+        installed_uri = ('http://{0}/api/v1/clusters/{'
+                         '1}/host_components?HostRoles/state=INSTALLED&'
+                         'HostRoles/host_name.in({2})'.format(
+                             ambari_info.get_address(), cluster_name,
+                             self._get_host_list(servers)))
         result = self._get(installed_uri, ambari_info)
         if result.status_code == 200:
             LOG.debug(
@@ -454,72 +495,75 @@ class AmbariClient():
 
             # query and start all non-client components on the given set of
             # hosts
-            #TODO(jspeidel): Provide request context
+            # TODO(jspeidel): Provide request context
             body = '{"HostRoles": {"state" : "STARTED"}}'
-            start_uri = 'http://{0}/api/v1/clusters/{'\
-                        '1}/host_components?HostRoles/state=INSTALLED&'\
-                        'HostRoles/host_name.in({2})'\
-                        '&HostRoles/component_name.in({3})'.format(
-                        ambari_info.get_address(), cluster_name,
-                        self._get_host_list(servers),
-                        ",".join(inclusion_list))
+            start_uri = ('http://{0}/api/v1/clusters/{'
+                         '1}/host_components?HostRoles/state=INSTALLED&'
+                         'HostRoles/host_name.in({2})'
+                         '&HostRoles/component_name.in({3})'.format(
+                             ambari_info.get_address(), cluster_name,
+                             self._get_host_list(servers),
+                             ",".join(inclusion_list)))
             self._exec_ambari_command(ambari_info, body, start_uri)
         else:
             raise ex.HadoopProvisionError(
-                'Unable to determine installed service '
-                'components in scaled instances.  status'
-                ' code returned = {0}'.format(result.status))
+                _('Unable to determine installed service '
+                  'components in scaled instances.  status'
+                  ' code returned = {0}').format(result.status))
 
     def wait_for_host_registrations(self, num_hosts, ambari_info):
         LOG.info(
-            'Waiting for all Ambari agents to register with server ...')
+            _LI('Waiting for all Ambari agents to register with server ...'))
 
         url = 'http://{0}/api/v1/hosts'.format(ambari_info.get_address())
         result = None
         json_result = None
 
-        #TODO(jspeidel): timeout
+        # TODO(jspeidel): timeout
         while result is None or len(json_result['items']) < num_hosts:
             context.sleep(5)
             try:
                 result = self._get(url, ambari_info)
                 json_result = json.loads(result.text)
 
-                LOG.info('Registered Hosts: {0} of {1}'.format(
-                    len(json_result['items']), num_hosts))
+                LOG.info(_LI('Registered Hosts: %(current_number)s of '
+                             '%(final_number)s'),
+                         {'current_number': len(json_result['items']),
+                          'final_number': num_hosts})
                 for hosts in json_result['items']:
                     LOG.debug('Registered Host: {0}'.format(
                         hosts['Hosts']['host_name']))
-            except requests.ConnectionError:
-                #TODO(jspeidel): max wait time
-                LOG.info('Waiting to connect to ambari server ...')
+            except Exception:
+                # TODO(jspeidel): max wait time
+                LOG.info(_LI('Waiting to connect to ambari server ...'))
 
     def update_ambari_admin_user(self, password, ambari_info):
         old_pwd = ambari_info.password
         user_url = 'http://{0}/api/v1/users/admin'.format(
             ambari_info.get_address())
-        update_body = '{{"Users":{{"roles":"admin","password":"{0}",' \
-                      '"old_password":"{1}"}} }}'.format(password, old_pwd)
+        update_body = ('{{"Users":{{"roles":"admin","password":"{0}",'
+                       '"old_password":"{1}"}} }}'.format(password, old_pwd))
 
         result = self._put(user_url, ambari_info, data=update_body)
 
         if result.status_code != 200:
-            raise ex.HadoopProvisionError('Unable to update Ambari admin user'
-                                          ' credentials: {0}'.format(
-                                          result.text))
+            raise ex.HadoopProvisionError(_('Unable to update Ambari admin '
+                                            'user credentials: {0}').format(
+                result.text))
 
     def add_ambari_user(self, user, ambari_info):
         user_url = 'http://{0}/api/v1/users/{1}'.format(
             ambari_info.get_address(), user.name)
 
-        create_body = '{{"Users":{{"password":"{0}","roles":"{1}"}} }}'. \
-            format(user.password, '%s' % ','.join(map(str, user.groups)))
+        create_body = ('{{"Users":{{"password":"{0}","roles":"{1}"}} }}'.
+                       format(user.password, '%s' %
+                                             ','.join(map(str, user.groups))))
 
         result = self._post(user_url, ambari_info, data=create_body)
 
         if result.status_code != 201:
             raise ex.HadoopProvisionError(
-                'Unable to create Ambari user: {0}'.format(result.text))
+                _('Unable to create Ambari user: {0}').format(result.text))
 
     def delete_ambari_user(self, user_name, ambari_info):
         user_url = 'http://{0}/api/v1/users/{1}'.format(
@@ -529,8 +573,9 @@ class AmbariClient():
 
         if result.status_code != 200:
             raise ex.HadoopProvisionError(
-                'Unable to delete Ambari user: {0}'
-                ' : {1}'.format(user_name, result.text))
+                _('Unable to delete Ambari user: %(user_name)s'
+                  ' : %(text)s') %
+                {'user_name': user_name, 'text': result.text})
 
     def configure_scaled_cluster_instances(self, name, cluster_spec,
                                            num_hosts, ambari_info):
@@ -551,6 +596,12 @@ class AmbariClient():
         self._install_and_start_components(
             name, servers, ambari_info, cluster_spec)
 
+    def decommission_cluster_instances(self, cluster, clusterspec, instances,
+                                       ambari_info):
+        raise exc.InvalidException(_('The HDP plugin does not support '
+                                     'the decommissioning of nodes '
+                                     'for HDP version 1.3.2'))
+
     def provision_cluster(self, cluster_spec, servers, ambari_info, name):
         self._add_cluster(ambari_info, name)
         self._add_configurations_to_cluster(cluster_spec, ambari_info, name)
@@ -566,12 +617,12 @@ class AmbariClient():
         try:
             ambari_info.host.remote().close_http_session(ambari_info.port)
         except exc.NotFoundException:
-            LOG.info("HTTP session is not cached")
+            LOG.info(_LI("HTTP session is not cached"))
 
     def _get_services_in_state(self, cluster_name, ambari_info, state):
-        services_url = 'http://{0}/api/v1/clusters/{1}/services?' \
-                       'ServiceInfo/state.in({2})'.format(
-                           ambari_info.get_address(), cluster_name, state)
+        services_url = ('http://{0}/api/v1/clusters/{1}/services?'
+                        'ServiceInfo/state.in({2})'.format(
+                            ambari_info.get_address(), cluster_name, state))
 
         result = self._get(services_url, ambari_info)
 
@@ -587,6 +638,6 @@ class AmbariClient():
         started_services = self._get_services_in_state(
             cluster_name, ambari_info, 'STARTED')
         for service in cluster_spec.services:
-            if service.deployed and not service.name in started_services:
+            if service.deployed and service.name not in started_services:
                 service.pre_service_start(cluster_spec, ambari_info,
                                           started_services)
