@@ -17,11 +17,13 @@ from oslo.config import cfg
 
 from sahara import conductor as c
 from sahara import context
+from sahara import exceptions as ex
+from sahara.i18n import _LE
 from sahara.openstack.common import log as logging
-from sahara.plugins import base as plugin_base
 from sahara.service.edp.binary_retrievers import dispatch
 from sahara.service.edp import job_manager as manager
-from sahara.service.edp.workflow_creator import workflow_factory as w_f
+from sahara.utils import edp
+from sahara.utils import proxy as p
 
 
 conductor = c.API
@@ -29,27 +31,24 @@ LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
+OPS = None
+
+
+def setup_edp_api(ops):
+    global OPS
+
+    OPS = ops
+
+
 def get_job_config_hints(job_type):
-    return w_f.get_possible_job_config(job_type)
+    return manager.get_job_config_hints(job_type)
 
 
 def execute_job(job_id, data):
-
     # Elements common to all job types
     cluster_id = data['cluster_id']
     configs = data.get('job_configs', {})
 
-    ctx = context.current()
-    cluster = conductor.cluster_get(ctx, cluster_id)
-    plugin = plugin_base.PLUGINS.get_plugin(cluster.plugin_name)
-    instance = plugin.get_oozie_server(cluster)
-
-    extra = {}
-    info = None
-    if CONF.use_namespaces and not CONF.use_floating_ips:
-        info = instance.remote().get_neutron_info()
-        extra['neutron'] = info
-
     # Not in Java job types but present for all others
     input_id = data.get('input_id', None)
     output_id = data.get('output_id', None)
@@ -58,12 +57,22 @@ def execute_job(job_id, data):
     # a superset for all job types
     job_ex_dict = {'input_id': input_id, 'output_id': output_id,
                    'job_id': job_id, 'cluster_id': cluster_id,
-                   'info': {'status': 'Pending'}, 'job_configs': configs,
-                   'extra': extra}
+                   'info': {'status': edp.JOB_STATUS_PENDING},
+                   'job_configs': configs, 'extra': {}}
     job_execution = conductor.job_execution_create(context.ctx(), job_ex_dict)
 
-    context.spawn("Starting Job Execution %s" % job_execution.id,
-                  manager.run_job, job_execution)
+    # check to use proxy user
+    if p.job_execution_requires_proxy_user(job_execution):
+        try:
+            p.create_proxy_user_for_job_execution(job_execution)
+        except ex.SaharaException as e:
+            LOG.exception(_LE("Can't run job execution '{0}' "
+                              "(reasons: {1})").format(job_execution.id, e))
+            conductor.job_execution_destroy(context.ctx(), job_execution)
+            raise e
+
+    OPS.run_edp_job(job_execution.id)
+
     return job_execution
 
 
