@@ -15,12 +15,18 @@
 
 import copy
 
+from oslo.config import cfg
+
 import sahara.exceptions as ex
+from sahara.i18n import _
 import sahara.service.api as api
 import sahara.service.validations.base as b
 import sahara.service.validations.cluster_templates as cl_tmpl
 
 
+CONF = cfg.CONF
+
+
 def _build_cluster_schema():
     cluster_schema = copy.deepcopy(cl_tmpl.CLUSTER_TEMPLATE_SCHEMA)
     cluster_schema['properties'].update({
@@ -50,7 +56,8 @@ def check_cluster_create(data, **kwargs):
         ct_id = data['cluster_template_id']
         b.check_cluster_template_exists(ct_id)
         if not data.get('node_groups'):
-            b.check_node_groups_in_cluster_templates(data['plugin_name'],
+            b.check_node_groups_in_cluster_templates(data['name'],
+                                                     data['plugin_name'],
                                                      data['hadoop_version'],
                                                      ct_id)
 
@@ -65,7 +72,7 @@ def check_cluster_create(data, **kwargs):
                                     default_image_id)
     else:
         raise ex.NotFoundException('default_image_id',
-                                   "'%s' field is not found")
+                                   _("'%s' field is not found"))
 
     b.check_all_configurations(data)
 
@@ -75,10 +82,19 @@ def check_cluster_create(data, **kwargs):
 
     if data.get('node_groups'):
         b.check_network_config(data['node_groups'])
+        b.check_cluster_hostnames_lengths(data['name'], data['node_groups'])
 
     neutron_net_id = _get_cluster_field(data, 'neutron_management_network')
     if neutron_net_id:
+        if not CONF.use_neutron:
+            raise ex.InvalidException(
+                _("'neutron_management_network' field can't be used "
+                  "with 'use_neutron=False'"))
         b.check_network_exists(neutron_net_id)
+    else:
+        if CONF.use_neutron:
+            raise ex.NotFoundException('neutron_management_network',
+                                       message=_("'%s' field is not found"))
 
 
 def _get_cluster_field(cluster, field):
