@@ -14,6 +14,7 @@
 # limitations under the License.
 
 import sahara.exceptions as e
+from sahara.i18n import _
 from sahara.service.edp import api
 from sahara.utils import edp
 
@@ -31,13 +32,7 @@ JOB_SCHEMA = {
         },
         "type": {
             "type": "string",
-            "enum": [
-                "Pig",
-                "Hive",
-                "MapReduce",
-                "MapReduce.Streaming",
-                "Java"
-            ],
+            "enum": edp.JOB_TYPES_ALL,
         },
         "mains": {
             "type": "array",
@@ -71,30 +66,36 @@ def _check_binaries(values):
     for job_binary in values:
         if not api.get_job_binary(job_binary):
             raise e.NotFoundException(job_binary,
-                                      "Job binary '%s' does not exist")
+                                      _("Job binary '%s' does not exist"))
 
 
 def check_mains_libs(data, **kwargs):
     mains = data.get("mains", [])
     libs = data.get("libs", [])
     job_type, subtype = edp.split_job_type(data.get("type"))
-    streaming = job_type == "MapReduce" and subtype == "Streaming"
+    streaming = (job_type == edp.JOB_TYPE_MAPREDUCE and
+                 subtype == edp.JOB_SUBTYPE_STREAMING)
 
-    # Pig or Hive flow has to contain script in mains, may also use libs
-    if job_type in ['Pig', 'Hive']:
+    # These types must have a value in mains and may also use libs
+    if job_type in [edp.JOB_TYPE_PIG, edp.JOB_TYPE_HIVE, edp.JOB_TYPE_SPARK]:
         if not mains:
-            raise e.InvalidDataException("%s flow requires main script" %
-                                         data.get("type"))
+            if job_type == edp.JOB_TYPE_SPARK:
+                msg = _(
+                    "%s job requires main application jar") % data.get("type")
+            else:
+                msg = _("%s flow requires main script") % data.get("type")
+            raise e.InvalidDataException(msg)
         # Check for overlap
         if set(mains).intersection(set(libs)):
-            raise e.InvalidDataException("'mains' and 'libs' overlap")
+            raise e.InvalidDataException(_("'mains' and 'libs' overlap"))
 
     else:
+        # Java and MapReduce require libs, but MapReduce.Streaming does not
         if not streaming and not libs:
-            raise e.InvalidDataException("%s flow requires libs" %
+            raise e.InvalidDataException(_("%s flow requires libs") %
                                          data.get("type"))
         if mains:
-            raise e.InvalidDataException("%s flow does not use mains" %
+            raise e.InvalidDataException(_("%s flow does not use mains") %
                                          data.get("type"))
 
     # Make sure that all referenced binaries exist
