@@ -15,18 +15,14 @@
 
 import sahara.exceptions as ex
 from sahara.i18n import _
-from sahara.plugins import base
+from sahara.plugins import base as plugin_base
 
 
-def plugin_update_validation_jsonschema():
-    return base.PLUGINS.get_plugin_update_validation_jsonschema()
+CONVERT_TO_TEMPLATE_SCHEMA = None
 
 
 def check_convert_to_template(plugin_name, version, **kwargs):
-    raise ex.InvalidReferenceException(
-        _("Requested plugin '%s' doesn't support converting config files "
-          "to cluster templates") % plugin_name)
-
-
-def check_plugin_update(plugin_name, data, **kwargs):
-    base.PLUGINS.validate_plugin_update(plugin_name, data)
+    if not plugin_base.PLUGINS.is_plugin_implements(plugin_name, 'convert'):
+        raise ex.InvalidException(
+            _("Requested plugin '%s' doesn't support converting config files "
+              "to cluster templates") % plugin_name)
