@@ -18,6 +18,7 @@ import logging
 from oslo.config import cfg
 
 from sahara import context
+from sahara.i18n import _LI
 from sahara.swift import utils as su
 from sahara.utils import xmlutils as x
 
@@ -28,15 +29,13 @@ HADOOP_SWIFT_AUTH_URL = 'fs.swift.service.sahara.auth.url'
 HADOOP_SWIFT_TENANT = 'fs.swift.service.sahara.tenant'
 HADOOP_SWIFT_USERNAME = 'fs.swift.service.sahara.username'
 HADOOP_SWIFT_PASSWORD = 'fs.swift.service.sahara.password'
+HADOOP_SWIFT_REGION = 'fs.swift.service.sahara.region'
+HADOOP_SWIFT_TRUST_ID = 'fs.swift.service.sahara.trust.id'
+HADOOP_SWIFT_DOMAIN_NAME = 'fs.swift.service.sahara.domain.name'
 
 
 def retrieve_tenant():
-    try:
-        return context.current().tenant_name
-    except RuntimeError:
-        LOG.exception("Cannot retrieve tenant for swift integration.")
-        #todo(slukjanov?) raise special error here
-        raise RuntimeError("Cannot retrieve tenant for swift integration")
+    return context.current().tenant_name
 
 
 def get_swift_configs():
@@ -46,8 +45,10 @@ def get_swift_configs():
             conf['value'] = su.retrieve_auth_url() + "tokens/"
         if conf['name'] == HADOOP_SWIFT_TENANT:
             conf['value'] = retrieve_tenant()
+        if CONF.os_region_name and conf['name'] == HADOOP_SWIFT_REGION:
+            conf['value'] = CONF.os_region_name
 
     result = [cfg for cfg in configs if cfg['value']]
-    LOG.info("Swift would be integrated with the following "
-             "params: %s", result)
+    LOG.info(_LI("Swift would be integrated with the following "
+             "params: %s"), result)
     return result
