@@ -43,9 +43,6 @@ COMMON_CONFIG_OPTS = [
     cfg.StrOpt('OS_TENANT_NAME',
                default='admin',
                help='Tenant name for OpenStack.'),
-    cfg.StrOpt('OS_TENANT_ID',
-               default=None,
-               help='Tenant ID for OpenStack.'),
     cfg.StrOpt('OS_AUTH_URL',
                default='http://127.0.0.1:5000/v2.0',
                help='URL for OpenStack.'),
@@ -62,7 +59,6 @@ COMMON_CONFIG_OPTS = [
                default='1.1',
                help='API version for Sahara.'),
     cfg.StrOpt('FLAVOR_ID',
-               default=None,
                help='OpenStack flavor ID for virtual machines. If you leave '
                     'the default value of this parameter, then flavor ID will '
                     'be created automatically, using nova client. The created '
@@ -113,7 +109,6 @@ COMMON_CONFIG_OPTS = [
                     'and/or digits)) for its uniqueness. In the end of tests '
                     'key pair will be deleted.'),
     cfg.StrOpt('PATH_TO_SSH_KEY',
-               default=None,
                help='Path to id_rsa key which is used with tests for remote '
                     'command execution. If you specify wrong path to key '
                     'then you will have the error "Private key file is '
@@ -122,7 +117,6 @@ COMMON_CONFIG_OPTS = [
                     '(private and public SSH keys) will be generated '
                     'automatically, using nova client.'),
     cfg.StrOpt('FLOATING_IP_POOL',
-               default=None,
                help='Pool name for floating IPs. If Sahara uses Nova '
                     'management network and auto assignment of IPs was '
                     'enabled then you should leave default value of this '
@@ -157,38 +151,29 @@ VANILLA_CONFIG_OPTS = [
                default='vanilla',
                help='Name of plugin.'),
     cfg.StrOpt('IMAGE_ID',
-               default=None,
                help='ID for image which is used for cluster creation. Also '
                     'you can specify image name or tag of image instead of '
                     'image ID. If you do not specify image related parameters '
                     'then image for cluster creation will be chosen by '
                     'tag "sahara_i_tests".'),
     cfg.StrOpt('IMAGE_NAME',
-               default=None,
                help='Name for image which is used for cluster creation. Also '
                     'you can specify image ID or tag of image instead of '
                     'image name. If you do not specify image related '
                     'parameters, then the image for cluster creation will be '
                     'chosen by tag "sahara_i_tests".'),
     cfg.StrOpt('IMAGE_TAG',
-               default=None,
                help='Tag for image which is used for cluster creation. Also '
                     'you can specify image ID or image name instead of tag of '
                     'image. If you do not specify image related parameters, '
                     'then image for cluster creation will be chosen by '
                     'tag "sahara_i_tests".'),
-    cfg.StrOpt('SSH_USERNAME',
-               default=None,
-               help='Username to get cluster node with SSH.'),
     cfg.StrOpt('HADOOP_VERSION',
                default='1.2.1',
                help='Version of Hadoop.'),
     cfg.StrOpt('HADOOP_USER',
                default='hadoop',
                help='Username which is used for access to Hadoop services.'),
-    cfg.StrOpt('HADOOP_DIRECTORY',
-               default='/usr/share/hadoop',
-               help='Directory where Hadoop jar files are located.'),
     cfg.StrOpt('HADOOP_EXAMPLES_JAR_PATH',
                default='/usr/share/hadoop/hadoop-examples-1.2.1.jar',
                help='Path to hadoop examples jar file.'),
@@ -226,9 +211,7 @@ VANILLA_CONFIG_OPTS = [
     cfg.BoolOpt('SKIP_EDP_TEST', default=False),
     cfg.BoolOpt('SKIP_MAP_REDUCE_TEST', default=False),
     cfg.BoolOpt('SKIP_SWIFT_TEST', default=False),
-    cfg.BoolOpt('SKIP_SCALING_TEST', default=False),
-    cfg.BoolOpt('SKIP_TRANSIENT_CLUSTER_TEST', default=False),
-    cfg.BoolOpt('ONLY_TRANSIENT_CLUSTER_TEST', default=False)
+    cfg.BoolOpt('SKIP_SCALING_TEST', default=False)
 ]
 
 
@@ -238,38 +221,29 @@ VANILLA_TWO_CONFIG_OPTS = [
                default='vanilla',
                help='Name of plugin.'),
     cfg.StrOpt('IMAGE_ID',
-               default=None,
                help='ID for image which is used for cluster creation. Also '
                     'you can specify image name or tag of image instead of '
                     'image ID. If you do not specify image related parameters '
                     'then image for cluster creation will be chosen by '
-                    'tag "savanna_i_tests".'),
+                    'tag "sahara_i_tests".'),
     cfg.StrOpt('IMAGE_NAME',
-               default=None,
                help='Name for image which is used for cluster creation. Also '
                     'you can specify image ID or tag of image instead of '
                     'image name. If you do not specify image related '
                     'parameters, then the image for cluster creation will be '
-                    'chosen by tag "savanna_i_tests".'),
+                    'chosen by tag "sahara_i_tests".'),
     cfg.StrOpt('IMAGE_TAG',
-               default=None,
                help='Tag for image which is used for cluster creation. Also '
                     'you can specify image ID or image name instead of tag of '
                     'image. If you do not specify image related parameters, '
                     'then image for cluster creation will be chosen by '
-                    'tag "savanna_i_tests".'),
-    cfg.StrOpt('SSH_USERNAME',
-               default=None,
-               help='Username to get cluster node with SSH.'),
+                    'tag "sahara_i_tests".'),
     cfg.StrOpt('HADOOP_VERSION',
                default='2.3.0',
                help='Version of Hadoop.'),
     cfg.StrOpt('HADOOP_USER',
                default='hadoop',
                help='Username which is used for access to Hadoop services.'),
-    cfg.StrOpt('HADOOP_DIRECTORY',
-               default='/opt/hadoop',
-               help='Directory where Hadoop jar files are located.'),
     cfg.StrOpt('HADOOP_EXAMPLES_JAR_PATH',
                default='/opt/hadoop/share/hadoop/mapreduce/'
                        'hadoop-mapreduce-examples-2.3.0.jar',
@@ -297,6 +271,9 @@ VANILLA_TWO_CONFIG_OPTS = [
                 },
                 help='Names for namenode, nodemanager and datanode '
                      'processes.'),
+    cfg.ListOpt('SKIP_EDP_JOB_TYPES',
+                default=[],
+                help='List of skipped EDP job types.'),
     cfg.BoolOpt('SKIP_ALL_TESTS_FOR_PLUGIN',
                 default=False,
                 help='If this flag is True, then all tests for Vanilla plugin '
@@ -309,6 +286,96 @@ VANILLA_TWO_CONFIG_OPTS = [
     cfg.BoolOpt('SKIP_SCALING_TEST', default=False)
 ]
 
+CDH_CONFIG_GROUP = cfg.OptGroup(name='CDH')
+CDH_CONFIG_OPTS = [
+    cfg.StrOpt('PLUGIN_NAME',
+               default='cdh',
+               help='Name of plugin.'),
+    cfg.StrOpt('IMAGE_ID',
+               default=None,
+               help='ID for image which is used for cluster creation. Also '
+                    'you can specify image name or tag of image instead of '
+                    'image ID. If you do not specify image related parameters '
+                    'then image for cluster creation will be chosen by '
+                    'tag "sahara_i_tests".'),
+    cfg.StrOpt('IMAGE_NAME',
+               default=None,
+               help='Name for image which is used for cluster creation. Also '
+                    'you can specify image ID or tag of image instead of '
+                    'image name. If you do not specify image related '
+                    'parameters, then the image for cluster creation will be '
+                    'chosen by tag "sahara_i_tests".'),
+    cfg.StrOpt('IMAGE_TAG',
+               default=None,
+               help='Tag for image which is used for cluster creation. Also '
+                    'you can specify image ID or image name instead of tag of '
+                    'image. If you do not specify image related parameters, '
+                    'then image for cluster creation will be chosen by '
+                    'tag "sahara_i_tests".'),
+    cfg.StrOpt('HADOOP_VERSION',
+               default='5',
+               help='Version of Hadoop.'),
+    cfg.StrOpt('HADOOP_USER',
+               default='hdfs',
+               help='Username which is used for access to Hadoop services.'),
+    cfg.StrOpt('HADOOP_EXAMPLES_JAR_PATH',
+               default='/usr/lib/hadoop-mapreduce'
+               '/hadoop-mapreduce-examples.jar',
+               help='Path to hadoop examples jar file.'),
+    cfg.StrOpt('HADOOP_LOG_DIRECTORY',
+               default='',
+               help='Directory where logs of completed jobs are located.'),
+    cfg.StrOpt('HADOOP_LOG_DIRECTORY_ON_VOLUME',
+               default='',
+               help='Directory where logs of completed jobs on volume mounted '
+                    'to node are located.'),
+    cfg.StrOpt('CDH_REPO_LIST_URL',
+               default='http://archive-primary.cloudera.com/cdh5/ubuntu'
+                       '/precise/amd64/cdh/cloudera.list'),
+    cfg.StrOpt('CM_REPO_LIST_URL',
+               default='http://archive-primary.cloudera.com/cm5/ubuntu'
+                       '/precise/amd64/cm/cloudera.list'),
+    cfg.StrOpt('CDH_APT_KEY_URL',
+               default='http://archive-primary.cloudera.com/cdh5/ubuntu'
+                       '/precise/amd64/cdh/archive.key'),
+    cfg.StrOpt('CM_APT_KEY_URL',
+               default='http://archive-primary.cloudera.com/cm5/ubuntu'
+                       '/precise/amd64/cm/archive.key'),
+    cfg.StrOpt('MANAGERNODE_FLAVOR',
+               default='3',
+               help='Id of flavor for manager-node'),
+    cfg.DictOpt('HADOOP_PROCESSES_WITH_PORTS',
+                default={
+                    'RESOURCEMANAGER': 8088,
+                    'NAMENODE': 50070,
+                    'SECONDARYNAMENODE': 50090,
+                    'NODEMANAGER': 8042,
+                    'DATANODE': 50075,
+                    'MANAGER': 7180,
+                    'JOBHISTORY': 19888,
+                    'OOZIE_SERVER': 11000
+                },
+                help='Hadoop process map with ports for CDH plugin.'),
+    cfg.DictOpt('PROCESS_NAMES',
+                default={
+                    'nn': 'NAMENODE',
+                    'tt': 'NODEMANAGER',
+                    'dn': 'DATANODE'
+                },
+                help='Names for namenode, nodemanager and datanode '
+                     'processes.'),
+    cfg.BoolOpt('SKIP_ALL_TESTS_FOR_PLUGIN',
+                default=False,
+                help='If this flag is True, then all tests for CDH plugin '
+                     'will be skipped.'),
+    cfg.BoolOpt('SKIP_CINDER_TEST', default=False),
+    cfg.BoolOpt('SKIP_CLUSTER_CONFIG_TEST', default=False),
+    cfg.BoolOpt('SKIP_EDP_TEST', default=False),
+    cfg.BoolOpt('SKIP_MAP_REDUCE_TEST', default=False),
+    cfg.BoolOpt('SKIP_SWIFT_TEST', default=False),
+    cfg.BoolOpt('SKIP_SCALING_TEST', default=False)
+]
+
 
 HDP_CONFIG_GROUP = cfg.OptGroup(name='HDP')
 HDP_CONFIG_OPTS = [
@@ -316,38 +383,40 @@ HDP_CONFIG_OPTS = [
                default='hdp',
                help='Name of plugin.'),
     cfg.StrOpt('IMAGE_ID',
-               default=None,
                help='ID for image which is used for cluster creation. Also '
                     'you can specify image name or tag of image instead of '
                     'image ID. If you do not specify image related '
                     'parameters, then image for cluster creation will be '
                     'chosen by tag "sahara_i_tests".'),
     cfg.StrOpt('IMAGE_NAME',
-               default=None,
                help='Name for image which is used for cluster creation. Also '
                     'you can specify image ID or tag of image instead of '
                     'image name. If you do not specify image related '
                     'parameters, then image for cluster creation will be '
                     'chosen by tag "sahara_i_tests".'),
     cfg.StrOpt('IMAGE_TAG',
-               default=None,
                help='Tag for image which is used for cluster creation. Also '
                     'you can specify image ID or image name instead of tag of '
                     'image. If you do not specify image related parameters, '
                     'then image for cluster creation will be chosen by '
                     'tag "sahara_i_tests".'),
-    cfg.StrOpt('SSH_USERNAME',
-               default=None,
-               help='Username to get cluster node with SSH.'),
+    cfg.ListOpt('MASTER_NODE_PROCESSES',
+                default=['JOBTRACKER', 'NAMENODE', 'SECONDARY_NAMENODE',
+                         'GANGLIA_SERVER', 'NAGIOS_SERVER',
+                         'AMBARI_SERVER', 'OOZIE_SERVER'],
+                help='A list of processes that will be launched '
+                     'on master node'),
+    cfg.ListOpt('WORKER_NODE_PROCESSES',
+                default=['TASKTRACKER', 'DATANODE', 'HDFS_CLIENT',
+                         'MAPREDUCE_CLIENT', 'OOZIE_CLIENT', 'PIG'],
+                help='A list of processes that will be launched '
+                     'on worker nodes'),
     cfg.StrOpt('HADOOP_VERSION',
                default='1.3.2',
                help='Version of Hadoop.'),
     cfg.StrOpt('HADOOP_USER',
                default='hdfs',
                help='Username which is used for access to Hadoop services.'),
-    cfg.StrOpt('HADOOP_DIRECTORY',
-               default='/usr/lib/hadoop',
-               help='Directory where Hadoop jar files are located.'),
     cfg.StrOpt('HADOOP_EXAMPLES_JAR_PATH',
                default='/usr/lib/hadoop/hadoop-examples.jar',
                help='Path to hadoop examples jar file.'),
@@ -396,15 +465,11 @@ HDP_CONFIG_OPTS = [
     cfg.BoolOpt('SKIP_SCALING_TEST', default=False)
 ]
 
-IDH2_CONFIG_GROUP = cfg.OptGroup(name='IDH2')
-IDH2_CONFIG_OPTS = [
+HDP2_CONFIG_GROUP = cfg.OptGroup(name='HDP2')
+HDP2_CONFIG_OPTS = [
     cfg.StrOpt('PLUGIN_NAME',
-               default='idh',
+               default='hdp',
                help='Name of plugin.'),
-    cfg.StrOpt('MANAGER_FLAVOR_ID',
-               default='3',
-               help='Flavor ID to Intel Manager. Intel manager requires '
-                    '>=4Gb RAM'),
     cfg.StrOpt('IMAGE_ID',
                default=None,
                help='ID for image which is used for cluster creation. Also '
@@ -426,37 +491,108 @@ IDH2_CONFIG_OPTS = [
                     'image. If you do not specify image related parameters, '
                     'then image for cluster creation will be chosen by '
                     'tag "sahara_i_tests".'),
-    cfg.StrOpt('SSH_USERNAME',
-               default=None,
-               help='Username to get cluster node with SSH.'),
+    cfg.ListOpt('MASTER_NODE_PROCESSES',
+                default=['NAMENODE', 'SECONDARY_NAMENODE', 'ZOOKEEPER_SERVER',
+                         'AMBARI_SERVER', 'HISTORYSERVER', 'RESOURCEMANAGER',
+                         'GANGLIA_SERVER', 'NAGIOS_SERVER', 'OOZIE_SERVER'],
+                help='A list of processes that will be launched '
+                     'on master node'),
+    cfg.ListOpt('WORKER_NODE_PROCESSES',
+                default=['HDFS_CLIENT', 'DATANODE', 'ZOOKEEPER_CLIENT',
+                         'MAPREDUCE2_CLIENT', 'YARN_CLIENT', 'NODEMANAGER',
+                         'PIG', 'OOZIE_CLIENT'],
+                help='A list of processes that will be launched '
+                     'on worker nodes'),
     cfg.StrOpt('HADOOP_VERSION',
-               default='2.5.1',
+               default='2.0.6',
                help='Version of Hadoop.'),
     cfg.StrOpt('HADOOP_USER',
                default='hdfs',
                help='Username which is used for access to Hadoop services.'),
-    cfg.StrOpt('HADOOP_DIRECTORY',
-               default='/usr/lib/hadoop',
-               help='Directory where Hadoop jar files are located.'),
-    cfg.StrOpt('HADOOP_EXAMPLES_JAR_PATH',
-               default='/usr/lib/hadoop/hadoop-examples.jar',
-               help='Path to hadoop examples jar file.'),
-    cfg.StrOpt('HADOOP_LOG_DIRECTORY',
-               default='/var/log/hadoop/userlogs',
-               help='Directory where log info about completed jobs is '
-                    'located.'),
-
+    cfg.IntOpt('SCALE_EXISTING_NG_COUNT',
+               default=1,
+               help='The number of hosts to add while scaling '
+                    'an existing node group.'),
+    cfg.IntOpt('SCALE_NEW_NG_COUNT',
+               default=1,
+               help='The number of hosts to add while scaling '
+                    'a new node group.'),
     cfg.DictOpt('HADOOP_PROCESSES_WITH_PORTS',
                 default={
-                    'jobtracker': 54311,
-                    'namenode': 50070,
-                    'tasktracker': 50060,
-                    'datanode': 50075,
-                    'secondarynamenode': 50090,
-                    'oozie': 11000
+                    'RESOURCEMANAGER': 8088,
+                    'NAMENODE': 8020,
+                    'HISTORYSERVER': 19888,
+                    'SECONDARY_NAMENODE': 50090,
+                    'OOZIE_SERVER': 11000
                 },
-                help='Hadoop process map with ports for IDH plugin.'),
+                help='Hadoop process map with ports for HDP plugin.'
+                ),
+    cfg.DictOpt('PROCESS_NAMES',
+                default={
+                    'nn': 'NAMENODE',
+                    'tt': 'NODEMANAGER',
+                    'dn': 'DATANODE'
+                },
+                help='Names for namenode, tasktracker and datanode '
+                     'processes.'),
+    cfg.BoolOpt('SKIP_ALL_TESTS_FOR_PLUGIN',
+                default=True,
+                help='If this flag is True, then all tests for HDP plugin '
+                     'will be skipped.'),
+    cfg.BoolOpt('SKIP_EDP_TEST', default=False),
+    cfg.BoolOpt('SKIP_SWIFT_TEST', default=False),
+    cfg.BoolOpt('SKIP_SCALING_TEST', default=False)
+]
 
+
+SPARK_CONFIG_GROUP = cfg.OptGroup(name='SPARK')
+SPARK_CONFIG_OPTS = [
+    cfg.StrOpt('PLUGIN_NAME',
+               default='spark',
+               help='Name of plugin.'),
+    cfg.StrOpt('IMAGE_ID',
+               default=None,
+               help='ID for image which is used for cluster creation. Also '
+                    'you can specify image name or tag of image instead of '
+                    'image ID. If you do not specify image related '
+                    'parameters, then image for cluster creation will be '
+                    'chosen by tag "sahara_i_tests".'),
+    cfg.StrOpt('IMAGE_NAME',
+               default=None,
+               help='Name for image which is used for cluster creation. Also '
+                    'you can specify image ID or tag of image instead of '
+                    'image name. If you do not specify image related '
+                    'parameters, then image for cluster creation will be '
+                    'chosen by tag "sahara_i_tests".'),
+    cfg.StrOpt('IMAGE_TAG',
+               default=None,
+               help='Tag for image which is used for cluster creation. Also '
+                    'you can specify image ID or image name instead of tag of '
+                    'image. If you do not specify image related parameters, '
+                    'then image for cluster creation will be chosen by '
+                    'tag "sahara_i_tests".'),
+    cfg.ListOpt('MASTER_NODE_PROCESSES',
+                default=['namenode', 'master'],
+                help='A list of processes that will be launched '
+                     'on master node'),
+    cfg.ListOpt('WORKER_NODE_PROCESSES',
+                default=['datanode', 'slave'],
+                help='A list of processes that will be launched '
+                     'on worker nodes'),
+    cfg.StrOpt('HADOOP_VERSION',
+               default='1.0.0',
+               help='Version of Spark (even though it says "HADOOP".'),
+    cfg.StrOpt('HADOOP_USER',
+               default='hdfs',
+               help='Username which is used for access to Hadoop services.'),
+    cfg.DictOpt('HADOOP_PROCESSES_WITH_PORTS',
+                default={
+                    'master': 7077,
+                    'namenode': 8020,
+                    'datanode': 50075
+                },
+                help='Spark process map with ports for spark plugin.'
+                ),
     cfg.DictOpt('PROCESS_NAMES',
                 default={
                     'nn': 'namenode',
@@ -465,113 +601,11 @@ IDH2_CONFIG_OPTS = [
                 },
                 help='Names for namenode, tasktracker and datanode '
                      'processes.'),
-
-    cfg.StrOpt(
-        'IDH_TARBALL_URL',
-        default='http://repo2.intelhadoop.com/setup/'
-                'setup-intelhadoop-2.5.1-en-evaluation.RHEL.tar.gz'
-    ),
-
-    cfg.StrOpt(
-        'IDH_REPO_URL',
-        default='http://repo2.intelhadoop.com/evaluation/en/RHEL/2.5.1/rpm'
-    ),
-
-    cfg.StrOpt(
-        'OS_REPO_URL',
-        default='http://mirror.centos.org/centos-6/6/os/x86_64'
-    ),
-
     cfg.BoolOpt('SKIP_ALL_TESTS_FOR_PLUGIN',
-                default=False,
-                help='If this flag is True, then all tests for IDH plugin '
+                default=True,
+                help='If this flag is True, then all tests for Spark plugin '
                      'will be skipped.'),
-    cfg.BoolOpt('SKIP_MAP_REDUCE_TEST', default=False),
-    cfg.BoolOpt('SKIP_SWIFT_TEST', default=True),
-    cfg.BoolOpt('SKIP_SCALING_TEST', default=False)
-]
-
-IDH3_CONFIG_GROUP = cfg.OptGroup(name='IDH3')
-IDH3_CONFIG_OPTS = [
-    cfg.StrOpt('PLUGIN_NAME',
-               default='idh',
-               help='Name of plugin.'),
-    cfg.StrOpt('MANAGER_FLAVOR_ID',
-               default='3',
-               help='Flavor ID to Intel Manager. Intel manager requires '
-                    '>=4Gb RAM'),
-    cfg.StrOpt('IMAGE_ID',
-               default=None,
-               help='ID for image which is used for cluster creation. Also '
-                    'you can specify image name or tag of image instead of '
-                    'image ID. If you do not specify image related '
-                    'parameters, then image for cluster creation will be '
-                    'chosen by tag "sahara_i_tests".'),
-    cfg.StrOpt('IMAGE_NAME',
-               default=None,
-               help='Name for image which is used for cluster creation. Also '
-                    'you can specify image ID or tag of image instead of '
-                    'image name. If you do not specify image related '
-                    'parameters, then image for cluster creation will be '
-                    'chosen by tag "sahara_i_tests".'),
-    cfg.StrOpt('IMAGE_TAG',
-               default=None,
-               help='Tag for image which is used for cluster creation. Also '
-                    'you can specify image ID or image name instead of tag of '
-                    'image. If you do not specify image related parameters, '
-                    'then image for cluster creation will be chosen by '
-                    'tag "sahara_i_tests".'),
-    cfg.StrOpt('SSH_USERNAME',
-               default=None,
-               help='Username to get cluster node with SSH.'),
-    cfg.StrOpt('HADOOP_VERSION',
-               default='3.0.2',
-               help='Version of Hadoop.'),
-    cfg.StrOpt('HADOOP_USER',
-               default='hdfs',
-               help='Username which is used for access to Hadoop services.'),
-    cfg.DictOpt('HADOOP_PROCESSES_WITH_PORTS',
-                default={
-                    'resourcemanager': 8032,
-                    'namenode': 50070,
-                    'tasktracker': 50060,
-                    'datanode': 50075,
-                    'secondarynamenode': 50090,
-                    'oozie': 11000
-                },
-                help='Hadoop process map with ports for IDH plugin.'),
-
-    cfg.DictOpt('PROCESS_NAMES',
-                default={
-                    'nn': 'namenode',
-                    'tt': 'nodemanager',
-                    'dn': 'datanode'
-                },
-                help='Names for namenode, tasktracker and datanode '
-                     'processes.'),
-
-    cfg.StrOpt(
-        'IDH_TARBALL_URL',
-        default='http://repo2.intelhadoop.com/setup/'
-                'setup-intelhadoop-3.0.2-en-evaluation.RHEL.tar.gz'
-    ),
-
-    cfg.StrOpt(
-        'IDH_REPO_URL',
-        default='http://repo2.intelhadoop.com/evaluation/'
-                'en/RHEL/3.0.2/rpm'
-    ),
-
-    cfg.StrOpt(
-        'OS_REPO_URL',
-        default='http://mirror.centos.org/centos-6/6/os/x86_64'
-    ),
-
-    cfg.BoolOpt('SKIP_ALL_TESTS_FOR_PLUGIN',
-                default=False,
-                help='If this flag is True, then all tests for IDH plugin '
-                     'will be skipped.'),
-    cfg.BoolOpt('SKIP_SWIFT_TEST', default=True),
+    cfg.BoolOpt('SKIP_EDP_TEST', default=False),
     cfg.BoolOpt('SKIP_SCALING_TEST', default=False)
 ]
 
@@ -592,7 +626,7 @@ class ITConfig:
                        '\nINFO: Configuration file "%s" not found  *\n'
                        '**************************************************'
                        % config)
-            print(RuntimeError(message), file=sys.stderr)
+            print(message, file=sys.stderr)
 
         else:
             config = os.path.join(
@@ -602,11 +636,12 @@ class ITConfig:
 
         register_config(cfg.CONF, COMMON_CONFIG_GROUP, COMMON_CONFIG_OPTS)
         register_config(cfg.CONF, VANILLA_CONFIG_GROUP, VANILLA_CONFIG_OPTS)
+        register_config(cfg.CONF, CDH_CONFIG_GROUP, CDH_CONFIG_OPTS)
         register_config(cfg.CONF, HDP_CONFIG_GROUP, HDP_CONFIG_OPTS)
-        register_config(cfg.CONF, IDH2_CONFIG_GROUP, IDH2_CONFIG_OPTS)
+        register_config(cfg.CONF, HDP2_CONFIG_GROUP, HDP2_CONFIG_OPTS)
         register_config(
             cfg.CONF, VANILLA_TWO_CONFIG_GROUP, VANILLA_TWO_CONFIG_OPTS)
-        register_config(cfg.CONF, IDH3_CONFIG_GROUP, IDH3_CONFIG_OPTS)
+        register_config(cfg.CONF, SPARK_CONFIG_GROUP, SPARK_CONFIG_OPTS)
 
         cfg.CONF(
             [], project='Sahara_integration_tests',
@@ -616,6 +651,7 @@ class ITConfig:
         self.common_config = cfg.CONF.COMMON
         self.vanilla_config = cfg.CONF.VANILLA
         self.vanilla_two_config = cfg.CONF.VANILLA_TWO
+        self.cdh_config = cfg.CONF.CDH
         self.hdp_config = cfg.CONF.HDP
-        self.idh2_config = cfg.CONF.IDH2
-        self.idh3_config = cfg.CONF.IDH3
+        self.hdp2_config = cfg.CONF.HDP2
+        self.spark_config = cfg.CONF.SPARK
