@@ -15,6 +15,8 @@
 
 import copy
 
+import testtools
+
 from sahara.conductor import manager
 from sahara import context
 from sahara import exceptions as ex
@@ -33,13 +35,15 @@ SAMPLE_CLUSTER = {
             "name": "ng_1",
             "flavor_id": "42",
             "node_processes": ["p1", "p2"],
-            "count": 1
+            "count": 1,
+            "security_groups": None
         },
         {
             "name": "ng_2",
             "flavor_id": "42",
             "node_processes": ["p3", "p4"],
-            "count": 3
+            "count": 3,
+            "security_groups": ["group1", "group2"]
         }
     ],
     "cluster_configs": {
@@ -76,14 +80,14 @@ class ClusterTest(test_base.ConductorManagerTestCase):
         lst = self.api.cluster_get_all(ctx)
         self.assertEqual(len(lst), 0)
 
-        with self.assertRaises(ex.NotFoundException):
+        with testtools.ExpectedException(ex.NotFoundException):
             self.api.cluster_destroy(ctx, cl_id)
 
     def test_duplicate_cluster_create(self):
         ctx = context.ctx()
         self.api.cluster_create(ctx, SAMPLE_CLUSTER)
 
-        with self.assertRaises(ex.DBDuplicateEntry):
+        with testtools.ExpectedException(ex.DBDuplicateEntry):
             self.api.cluster_create(ctx, SAMPLE_CLUSTER)
 
     def test_cluster_fields(self):
@@ -93,7 +97,7 @@ class ClusterTest(test_base.ConductorManagerTestCase):
 
         for key, val in SAMPLE_CLUSTER.items():
             if key == 'node_groups':
-                #this will be checked separately
+                # this will be checked separately
                 continue
             self.assertEqual(val, cl_db_obj.get(key),
                              "Key not found %s" % key)
@@ -112,6 +116,8 @@ class ClusterTest(test_base.ConductorManagerTestCase):
             ng.pop("volumes_per_node")
             ng.pop("floating_ip_pool")
             ng.pop("image_username")
+            ng.pop("open_ports")
+            ng.pop("auto_security_group")
             ng.pop("tenant_id")
 
         self.assertEqual(SAMPLE_CLUSTER["node_groups"],
@@ -142,7 +148,7 @@ class ClusterTest(test_base.ConductorManagerTestCase):
         get_cl_obj = self.api.cluster_get(ctx, _id)
         self.assertEqual(updated_cl, get_cl_obj)
 
-        with self.assertRaises(ex.NotFoundException):
+        with testtools.ExpectedException(ex.NotFoundException):
             self.api.cluster_update(ctx, "bad_id", {"status": "Active"})
 
     def _ng_in_cluster(self, cluster_db_obj, ng_id):
@@ -205,7 +211,7 @@ class ClusterTest(test_base.ConductorManagerTestCase):
 
         self.assertFalse(found_ng, "Node Group is still in a CLuster")
 
-        with self.assertRaises(ex.NotFoundException):
+        with testtools.ExpectedException(ex.NotFoundException):
             self.api.node_group_remove(ctx, ng_id)
 
     def _add_instance(self, ctx, ng_id):
@@ -279,5 +285,5 @@ class ClusterTest(test_base.ConductorManagerTestCase):
 
             self.assertEqual(count, ng["count"])
 
-        with self.assertRaises(ex.NotFoundException):
+        with testtools.ExpectedException(ex.NotFoundException):
             self.api.instance_remove(ctx, instance_id)
