@@ -13,19 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import unittest2
+import testtools
 
 import sahara.exceptions as ex
-from sahara.service.edp.workflow_creator import hive_workflow as hw
-from sahara.service.edp.workflow_creator import java_workflow as jw
-from sahara.service.edp.workflow_creator import mapreduce_workflow as mrw
-from sahara.service.edp.workflow_creator import pig_workflow as pw
+from sahara.service.edp.oozie.workflow_creator import hive_workflow as hw
+from sahara.service.edp.oozie.workflow_creator import java_workflow as jw
+from sahara.service.edp.oozie.workflow_creator import mapreduce_workflow as mrw
+from sahara.service.edp.oozie.workflow_creator import pig_workflow as pw
 from sahara.utils import patches as p
 
 
-class TestPigWorkflowCreator(unittest2.TestCase):
+class TestPigWorkflowCreator(testtools.TestCase):
 
     def setUp(self):
+        super(TestPigWorkflowCreator, self).setUp()
         p.patch_minidom_writexml()
         self.prepare = {'delete': ['delete_dir_1', 'delete_dir_2'],
                         'mkdir': ['mkdir_1']}
@@ -59,7 +60,7 @@ class TestPigWorkflowCreator(unittest2.TestCase):
         self.assertNotIn(mr_action, res)
 
         mr_workflow = mrw.MapReduceWorkFlowCreator()
-        with self.assertRaises(ex.NotFoundException):
+        with testtools.ExpectedException(ex.NotFoundException):
             mr_workflow.build_workflow_xml(self.prepare, self.job_xml,
                                            self.configuration, self.files,
                                            self.archives, {'bogus': 'element'})
@@ -74,9 +75,9 @@ class TestPigWorkflowCreator(unittest2.TestCase):
       <job-tracker>${jobTracker}</job-tracker>
       <name-node>${nameNode}</name-node>
       <prepare>
-        <mkdir path="mkdir_1"/>
         <delete path="delete_dir_1"/>
         <delete path="delete_dir_2"/>
+        <mkdir path="mkdir_1"/>
       </prepare>
       <job-xml>job_xml.xml</job-xml>
       <configuration>
@@ -112,9 +113,9 @@ class TestPigWorkflowCreator(unittest2.TestCase):
       <job-tracker>${jobTracker}</job-tracker>
       <name-node>${nameNode}</name-node>
       <prepare>
-        <mkdir path="mkdir_1"/>
         <delete path="delete_dir_1"/>
         <delete path="delete_dir_2"/>
+        <mkdir path="mkdir_1"/>
       </prepare>
       <job-xml>job_xml.xml</job-xml>
       <configuration>
@@ -150,9 +151,9 @@ class TestPigWorkflowCreator(unittest2.TestCase):
       <job-tracker>${jobTracker}</job-tracker>
       <name-node>${nameNode}</name-node>
       <prepare>
-        <mkdir path="mkdir_1"/>
         <delete path="delete_dir_1"/>
         <delete path="delete_dir_2"/>
+        <mkdir path="mkdir_1"/>
       </prepare>
       <job-xml>job_xml.xml</job-xml>
       <configuration>
@@ -166,8 +167,8 @@ class TestPigWorkflowCreator(unittest2.TestCase):
         </property>
       </configuration>
       <script>script.q</script>
-      <param>key2=value2</param>
       <param>key=value</param>
+      <param>key2=value2</param>
       <file>file1</file>
       <file>file2</file>
       <archive>arch1</archive>
@@ -192,9 +193,9 @@ class TestPigWorkflowCreator(unittest2.TestCase):
       <job-tracker>${jobTracker}</job-tracker>
       <name-node>${nameNode}</name-node>
       <prepare>
-        <mkdir path="mkdir_1"/>
         <delete path="delete_dir_1"/>
         <delete path="delete_dir_2"/>
+        <mkdir path="mkdir_1"/>
       </prepare>
       <job-xml>job_xml.xml</job-xml>
       <configuration>
