@@ -14,6 +14,8 @@
 # limitations under the License.
 
 import mock
+import six
+import testtools
 
 from sahara import exceptions
 from sahara import main
@@ -25,6 +27,7 @@ from sahara.tests.unit.service.validation import utils as u
 
 class TestClusterCreateValidation(u.ValidationTestCase):
     def setUp(self):
+        super(TestClusterCreateValidation, self).setUp()
         self._create_object_fun = c.check_cluster_create
         self.scheme = c.CLUSTER_SCHEMA
         api.plugin_base.setup_plugins()
@@ -165,6 +168,7 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_create_v_wrong_network(self):
+        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "test-name",
@@ -178,10 +182,64 @@ class TestClusterCreateValidation(u.ValidationTestCase):
                                                "94ce-b6df85a68332 not found")
         )
 
+    def test_cluster_create_mixed_nova_neutron(self):
+        self._assert_create_object_validation(
+            data={
+                'name': "test-name",
+                'plugin_name': "vanilla",
+                'hadoop_version': "1.2.1",
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': '53a36917-ab9f-4589-'
+                                              '94ce-b6df85a68332'
+            },
+            bad_req_i=(1, 'INVALID_REFERENCE',
+                       "'neutron_management_network' field can't "
+                       "be used with 'use_neutron=False'")
+        )
+
+    def test_cluster_create_v_missing_network(self):
+        self.override_config("use_neutron", True)
+        self._assert_create_object_validation(
+            data={
+                'name': "test-name",
+                'plugin_name': "vanilla",
+                'hadoop_version': "1.2.1",
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000'
+            },
+            bad_req_i=(1, 'NOT_FOUND',
+                       "'neutron_management_network' field is not found")
+        )
+
+    def test_cluster_create_v_long_instance_names(self):
+        self._assert_create_object_validation(
+            data={
+                'name': "long-long-cluster-name",
+                'plugin_name': "vanilla",
+                'hadoop_version': "1.2.1",
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        "name": "long-long-long-very-long-node-group-name",
+                        "node_processes": ["namenode"],
+                        "flavor_id": "42",
+                        "count": 100,
+                    }
+                ]
+            },
+            bad_req_i=(1, 'INVALID_REFERENCE',
+                       "Composite hostname long-long-cluster-name-long-long-"
+                       "long-very-long-node-group-name-100.novalocal "
+                       "in provisioned cluster exceeds maximum limit 64 "
+                       "characters")
+        )
+
     def test_cluster_create_v_cluster_configs(self):
         self._assert_cluster_configs_validation(True)
 
     def test_cluster_create_v_right_data(self):
+        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "testname",
@@ -202,6 +260,83 @@ class TestClusterCreateValidation(u.ValidationTestCase):
     def test_cluster_create_v_default_image_required_tags(self):
         self._assert_cluster_default_image_tags_validation()
 
+    def test_cluster_create_security_groups(self):
+        self.override_config("use_neutron", True)
+        self._assert_create_object_validation(
+            data={
+                'name': "testname",
+                'plugin_name': "vanilla",
+                'hadoop_version': "1.2.1",
+                'user_keypair_id': 'test_keypair',
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        "name": "nodegroup",
+                        "node_processes": ["namenode"],
+                        "flavor_id": "42",
+                        "count": 100,
+                        'security_groups': ['group1', 'group2'],
+                        'floating_ip_pool':
+                            'd9a3bebc-f788-4b81-9a93-aa048022c1ca'
+                    }
+                ]
+            }
+        )
+
+    def test_cluster_create_security_groups_by_ids(self):
+        self.override_config("use_neutron", True)
+        self._assert_create_object_validation(
+            data={
+                'name': "testname",
+                'plugin_name': "vanilla",
+                'hadoop_version': "1.2.1",
+                'user_keypair_id': 'test_keypair',
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        "name": "nodegroup",
+                        "node_processes": ["namenode"],
+                        "flavor_id": "42",
+                        "count": 100,
+                        'security_groups': ['2', '3'],
+                        'floating_ip_pool':
+                            'd9a3bebc-f788-4b81-9a93-aa048022c1ca'
+                    }
+                ]
+            }
+        )
+
+    def test_cluster_missing_security_groups(self):
+        self.override_config("use_neutron", True)
+        self._assert_create_object_validation(
+            data={
+                'name': "testname",
+                'plugin_name': "vanilla",
+                'hadoop_version': "1.2.1",
+                'user_keypair_id': 'test_keypair',
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        "name": "nodegroup",
+                        "node_processes": ["namenode"],
+                        "flavor_id": "42",
+                        "count": 100,
+                        'security_groups': ['group1', 'group3'],
+                        'floating_ip_pool':
+                            'd9a3bebc-f788-4b81-9a93-aa048022c1ca'
+                    }
+                ]
+            },
+            bad_req_i=(1, 'INVALID_REFERENCE',
+                       "Security group 'group3' not found")
+        )
+
 
 class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
     """Tests for valid flavor on cluster create.
@@ -331,15 +466,16 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             'default_image_id': '550e8400-e29b-41d4-a716-446655440000'
         }
         for values in [data, data1]:
-            with self.assertRaises(exceptions.InvalidException):
+            with testtools.ExpectedException(exceptions.InvalidException):
+                patchers = u.start_patch(False)
                 try:
-                    patchers = u.start_patch(False)
                     c.check_cluster_create(values)
-                    u.stop_patch(patchers)
                 except exceptions.InvalidException as e:
                     self.assertEqual("Requested flavor '10' not found",
-                                     e.message)
+                                     six.text_type(e))
                     raise e
+                finally:
+                    u.stop_patch(patchers)
 
     def test_cluster_create_cluster_tmpl_node_group_mixin(self):
         ng_id = self._create_node_group_template(flavor='10')
@@ -391,12 +527,12 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             ],
             'default_image_id': '550e8400-e29b-41d4-a716-446655440000'
         }
-        with self.assertRaises(exceptions.InvalidException):
+        with testtools.ExpectedException(exceptions.InvalidException):
             try:
                 patchers = u.start_patch(False)
                 c.check_cluster_create(data)
                 u.stop_patch(patchers)
             except exceptions.InvalidException as e:
                 self.assertEqual("Requested flavor '23' not found",
-                                 e.message)
+                                 six.text_type(e))
                 raise e
