@@ -13,15 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import functools
 import random
-from unittest import mock
 
 import fixtures
+import mock
 import six
 import testtools
 
 from sahara import context
 from sahara import exceptions as ex
+from sahara.tests.unit import base as test_base
 
 
 rnd = random.Random()
@@ -53,7 +55,7 @@ class ContextTest(testtools.TestCase):
                 for i in six.moves.range(400):
                     tg.spawn('add %i' % i, self._add_element, lst, i)
 
-            self.assertEqual(400, len(lst))
+            self.assertEqual(len(lst), 400)
 
     def test_thread_group_waits_threads_if_spawning_exception(self):
         lst = []
@@ -65,7 +67,7 @@ class ContextTest(testtools.TestCase):
 
                 raise RuntimeError()
 
-        self.assertEqual(400, len(lst))
+        self.assertEqual(len(lst), 400)
 
     def test_thread_group_waits_threads_if_child_exception(self):
         lst = []
@@ -77,7 +79,7 @@ class ContextTest(testtools.TestCase):
                 for i in six.moves.range(400):
                     tg.spawn('add %i' % i, self._add_element, lst, i)
 
-        self.assertEqual(400, len(lst))
+        self.assertEqual(len(lst), 400)
 
     def test_thread_group_handles_spawning_exception(self):
         with testtools.ExpectedException(TestException):
@@ -117,7 +119,7 @@ class ContextTest(testtools.TestCase):
         context._wrapper(None, 'test thread', tg, func)
 
         self.assertIsNotNone(tg.exc)
-        self.assertEqual('test thread', tg.failed_thread)
+        self.assertEqual(tg.failed_thread, 'test thread')
 
     def test_is_auth_capable_for_admin_ctx(self):
         ctx = context.ctx()
@@ -135,3 +137,31 @@ class ContextTest(testtools.TestCase):
 
 class TestException(Exception):
     pass
+
+
+class GetAuthURITest(test_base.SaharaTestCase):
+    def setUp(self):
+        super(GetAuthURITest, self).setUp()
+
+        self.override_auth_config = functools.partial(
+            self.override_config, group='keystone_authtoken')
+
+    def test_get_auth_url_from_auth_uri_param(self):
+        self.override_auth_config('auth_uri', 'http://pony:5000/v2.0')
+        self.assertEqual('http://pony:5000/v2.0', context._get_auth_uri())
+
+    def test_get_auth_uri_from_identity_uri(self):
+        self.override_auth_config('identity_uri', 'http://spam:35357')
+        self.assertEqual('http://spam:35357/v3', context._get_auth_uri())
+
+        self.override_config('use_identity_api_v3', False)
+        self.assertEqual('http://spam:35357/v2.0', context._get_auth_uri())
+
+    def test_get_auth_uri_from_auth_params(self):
+        self.override_auth_config('auth_host', 'eggs')
+        self.override_auth_config('auth_port', 12345)
+        self.override_auth_config('auth_protocol', 'http')
+        self.assertEqual('http://eggs:12345/v3', context._get_auth_uri())
+
+        self.override_config('use_identity_api_v3', False)
+        self.assertEqual('http://eggs:12345/v2.0', context._get_auth_uri())
