@@ -14,32 +14,28 @@
 # limitations under the License.
 
 
-from oslo_utils import uuidutils
+import uuid
+
+import six
 
 from sahara.conductor import resource as r
 
 
 def create_cluster(name, tenant, plugin, version, node_groups, **kwargs):
-    dct = {'id': uuidutils.generate_uuid(), 'name': name,
+    dct = {'id': six.text_type(uuid.uuid4()), 'name': name,
            'tenant_id': tenant, 'plugin_name': plugin,
            'hadoop_version': version, 'node_groups': node_groups,
-           'cluster_configs': {}, "sahara_info": {}, 'is_protected': False}
+           'cluster_configs': {}, "sahara_info": {}}
     dct.update(kwargs)
     return r.ClusterResource(dct)
 
 
-def make_ng_dict(name, flavor, processes, count, instances=None,
-                 volumes_size=None, node_configs=None, **kwargs):
-    node_configs = node_configs or {}
+def make_ng_dict(name, flavor, processes, count, instances=None, **kwargs):
     instances = instances or []
-    dct = {'id': uuidutils.generate_uuid(), 'name': name,
-           'volumes_size': volumes_size, 'flavor_id': flavor,
-           'node_processes': processes, 'count': count,
-           'instances': instances, 'node_configs': node_configs,
+    dct = {'name': name, 'flavor_id': flavor, 'node_processes': processes,
+           'count': count, 'instances': instances, 'node_configs': {},
            'security_groups': None, 'auto_security_group': False,
-           'availability_zone': None, 'volumes_availability_zone': None,
-           'open_ports': [], 'is_proxy_gateway': False,
-           'volume_local_to_instance': False}
+           'open_ports': []}
     dct.update(kwargs)
     return dct
 
