@@ -13,16 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+import testtools
 
-from sahara.tests.unit import base
 from sahara.utils import general
 
 
-class UtilsGeneralTest(base.SaharaWithDbTestCase):
-    def setUp(self):
-        super(UtilsGeneralTest, self).setUp()
-
+class UtilsGeneralTest(testtools.TestCase):
     def test_find_dict(self):
         iterable = [
             {
@@ -43,25 +39,10 @@ class UtilsGeneralTest(base.SaharaWithDbTestCase):
 
         self.assertEqual({"a": 1, "b": 2, "c": 3},
                          general.find_dict(iterable, a=1, b=2))
-        self.assertIsNone(general.find_dict(iterable, z=4))
-
-    def test_find(self):
-        lst = [mock.Mock(a=5), mock.Mock(b=5), mock.Mock(a=7, b=7)]
-        self.assertEqual(lst[0], general.find(lst, a=5))
-        self.assertEqual(lst[1], general.find(lst, b=5))
-        self.assertIsNone(general.find(lst, a=8))
-        self.assertEqual(lst[2], general.find(lst, a=7))
-        self.assertEqual(lst[2], general.find(lst, a=7, b=7))
 
     def test_generate_instance_name(self):
         inst_name = "cluster-worker-001"
         self.assertEqual(
-            inst_name, general.generate_instance_name("cluster", "worker", 1))
+            general.generate_instance_name("cluster", "worker", 1), inst_name)
         self.assertEqual(
-            inst_name, general.generate_instance_name("CLUSTER", "WORKER", 1))
-
-    def test_get_by_id(self):
-        lst = [mock.Mock(id=5), mock.Mock(id=7)]
-        self.assertIsNone(general.get_by_id(lst, 9))
-        self.assertEqual(lst[0], general.get_by_id(lst, 5))
-        self.assertEqual(lst[1], general.get_by_id(lst, 7))
+            general.generate_instance_name("CLUSTER", "WORKER", 1), inst_name)
