@@ -21,7 +21,7 @@ import pkg_resources as pkg
 from sahara import version
 
 
-## hadoop.xml related utils
+# hadoop.xml related utils
 
 def load_hadoop_xml_defaults(file_name):
     doc = load_xml_document(file_name)
@@ -37,19 +37,16 @@ def load_hadoop_xml_defaults(file_name):
     return configs
 
 
-def load_hadoop_xml_defaults_with_type_and_locale(file_name):
-    doc = load_xml_document(file_name)
+def parse_hadoop_xml_with_name_and_value(data):
+    doc = xml.parseString(data)
     configs = []
     prop = doc.getElementsByTagName('property')
     for elements in prop:
         configs.append({
             'name': _get_text_from_node(elements, 'name'),
-            'value': _get_text_from_node(elements, 'value'),
-            'type': _get_text_from_node(elements, 'valuetype'),
-            'description': _adjust_field(
-                _get_text_from_node(
-                    _get_node_element(elements, 'description'), 'en'))
+            'value': _get_text_from_node(elements, 'value')
         })
+
     return configs
 
 
@@ -74,15 +71,15 @@ def create_hadoop_xml(configs, config_filter=None):
     if config_filter is not None:
         default_configs = [cfg['name'] for cfg in config_filter]
 
-    for name, value in configs.items():
+    for name in sorted(configs):
         if name in default_configs or config_filter is None:
-            add_property_to_configuration(doc, name, value)
+            add_property_to_configuration(doc, name, configs[name])
 
     # Return newly created XML
     return doc.toprettyxml(indent="  ")
 
 
-## basic utils
+# basic utils
 
 def load_xml_document(file_name, strip=False):
     fname = pkg.resource_filename(
@@ -113,9 +110,9 @@ def add_property_to_configuration(doc, name, value):
 
 def add_properties_to_configuration(doc, parent_for_conf, configs):
     get_and_create_if_not_exist(doc, parent_for_conf, 'configuration')
-    for n, v in configs.items():
+    for n in sorted(configs):
         if n:
-            add_property_to_configuration(doc, n, v)
+            add_property_to_configuration(doc, n, configs[n])
 
 
 def add_child(doc, parent, tag_to_add):
@@ -148,10 +145,10 @@ def add_text_element_to_element(doc, parent, element, value):
 
 
 def add_equal_separated_dict(doc, parent_tag, each_elem_tag, value):
-    for k, v in value.items():
+    for k in sorted(value):
         if k:
             add_text_element_to_tag(doc, parent_tag, each_elem_tag,
-                                    "%s=%s" % (k, v))
+                                    "%s=%s" % (k, value[k]))
 
 
 def add_tagged_list(doc, parent_tag, each_elem_tag, values):
